#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAF0HpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHjarVdblusoDPxnFbMEQAjEcnieMzuY5U8JbHeSTnfS93YcGwWDEKqiIGb8'
    b'9+80/+DjmcQEThJzjBafkEP2BYbY/Snr6WxYz/Xxxyv8vqs31wuPKkJJ+6fEo/1Z7y4Huyiw'
    b'+MaRtONFvX+Rw+FfHhwdI5NGpHY/HOXDEfn9wh0Oyp6WjVnS7RTq2GU/ZyL7NvoIch/2p98J'
    b'2euMccj7QY4snp78DoD0doYKDIenJ7yBxbADyXqezpCQZ3myN1GZR1Quy31R/wAKxV1vUHGf'
    b'zHiVT+sdP9QfDs1K8c3I1K6R7+pLuth1l2S95+xi5hx7diVEpDQek7qyowYaVqScVreIK+Fm'
    b'2GldGZcYsLcB8m6brbiay84DlumC66646cYqm2sIMfjhE0rvG4DSOqHks29kDXAKernpE2Xq'
    b'wMtTA7yEWn/F4ta4eQ3XnGDg7tDSOzhzSgWjj9+4vnQ0p1LeOStXrhCXVxIiDEVOn2gFQNw8'
    b'ecQrwef1+FFcCQjySrNggsXW7aKyO7ilPKIFNKEho9xrzaV+OECKMDYjGEdAwEaQ30Vnk/fJ'
    b'OeRRgE+BI/EUfAUEjtl3ROkDUQQ44nVs9ElutfXsdzU0C0AwRUqAJlMBVgHCBv6kIOBQYeLA'
    b'zJETC2cukWKIHGNMUcWvJEohcYopJUk5FSEJwhIliRjJUrLPBHHkHHPKknMuBYMWeC7oXdCg'
    b'lOor1VC5xpqq1FxLA31aaNxiS01My61036lDJ3rsqUvPvQw3QKURBo840pCRR5mg2qQZJs84'
    b'05SZZ7lQc2bD+ul6HzV3ouYXUtowXaiha0qnC6dywooZEPPBAfGkCIDQXjGz4kLwRqFTzGyG'
    b'shF7RMkKTneKGBAMw3me7sLuA7k73EwIf4WbP5EzCt1vIGcUui+Q+4zbE9S67jbNklkI6TLU'
    b'pFrC8kOj4gVfyOL7pflphx86mmJ9HXMe5hu+zIsGBG9vxWXejGfWFOvwfhtcuIcRG1ize9Vo'
    b'KMvqX/S88H05RcoyR6Du1fkcFfBqfTGD3WCikpjymNg20uwuMPbBKFoG1oPFi5InpJZT10mw'
    b'3qsujp4a+K1GBP9Kbl1kHG6hGdDSZdvb0jxWaIndzC2Tm6QSUq91OUmcR8z68hi8HWO2iWRP'
    b'nzsyh2XUZ6CdYs1Kwd71Mnt6Wtq5MmOdFFHTd9aW0bHgkLPq3Omsy4jf4m/uOAN4F5jZziAK'
    b'tJQNFdZfmdm1PjlNIh3M1918ghbYp42+OKK7wvRY9T+Y1ZqUeW9WLh5m+EyBHABFMJUhfXkj'
    b'GxX9hYnCFEKh1kAAAAGNDHvmazQoVYds5ZJ6pCYahZEP9uccEg6dMQPEVEEcVnamZrcRcJJ8'
    b'QqCjNIdxNVdjVSCqM7zOtcOod8xM7Fr5mKB5TnqPQmeHU1ULB61u83yuXjVaLJi3wdkQUa/F'
    b'frvqG7T1tZ6dHWCYlyrBawMYWVyDvmN7WvOyeWQH7WZFjbGpQEZGlL2wrNWFsxt6dzXEmyFo'
    b'hb8nOK54jtgiJO4k+BWWMsecHHKldjtyo8l/xE/zQNBv+Yk9D3ctOAIQFMJu4WpeFcLcSYR8'
    b'oyN1JQMbNijYd77zDZHMpWHLkI58JGz3s8gSnaV3h/pk1/2XImlu1NJ+dH0hlRpd5Y7jZ9b1'
    b'EdcugkMVpHwrg0pIaZPCc70/G4ENoOlIufg9NdDJfMfWn5DVfMfWn5DVfGbr2Kj2iNDPXL5k'
    b'qiY74l/pTTwHgX7KUvOOjL5kKbTTdKp7NSL0TTzW82GCLIa59C+cOl/WDmBT59na7dZAqDfn'
    b'C7+kErV14os/+8sJatUPzmzXGeEemCsR5hfW62pu3szEzS6pmHvofrS324GpdkacN8+E7Env'
    b'BKyd4pjj6g1XyGJu7UOMLhaav4X9Ofw/gf3hSGD+5Az7LHzzl2Bd/czro+N7pbkb4l4ufuTL'
    b'/EIwbzia+NMChTf/A2rfAIuBtwsVAAABhWlDQ1BJQ0MgcHJvZmlsZQAAeJx9kT1Iw1AUhU9T'
    b'pSIVByuKOGSoThaKijhqFYpQIdQKrTqYvPRHaNKQpLg4Cq4FB38Wqw4uzro6uAqC4A+Im5uT'
    b'oouUeF9SaBHjhcf7OO+ew3v3AUK9zDSrIw5oum2mkwkxm1sRQ68IYAD9iCMkM8uYlaQUfOvr'
    b'nrqp7mI8y7/vz+pR8xYDAiLxDDNMm3ideGrTNjjvE0dYSVaJz4nHTLog8SPXFY/fOBddFnhm'
    b'xMyk54gjxGKxjZU2ZiVTI54kjqqaTvlC1mOV8xZnrVxlzXvyF4bz+vIS12kNI4kFLEKCCAVV'
    b'bKAMGzHadVIspOk84eMfcv0SuRRybYCRYx4VaJBdP/gf/J6tVZgY95LCCaDzxXE+RoDQLtCo'
    b'Oc73seM0ToDgM3Clt/yVOjD9SXqtpUWPgN5t4OK6pSl7wOUOMPhkyKbsSkFaQqEAvJ/RN+WA'
    b'vluge9WbW/Mcpw9AhmaVugEODoHRImWv+by7q31u//Y05/cDZsByou+2BFYAAA+gaVRYdFhN'
    b'TDpjb20uYWRvYmUueG1wAAAAAAA8P3hwYWNrZXQgYmVnaW49Iu+7vyIgaWQ9Ilc1TTBNcENl'
    b'aGlIenJlU3pOVGN6a2M5ZCI/Pgo8eDp4bXBtZXRhIHhtbG5zOng9ImFkb2JlOm5zOm1ldGEv'
    b'IiB4OnhtcHRrPSJYTVAgQ29yZSA0LjQuMC1FeGl2MiI+CiA8cmRmOlJERiB4bWxuczpyZGY9'
    b'Imh0dHA6Ly93d3cudzMub3JnLzE5OTkvMDIvMjItcmRmLXN5bnRheC1ucyMiPgogIDxyZGY6'
    b'RGVzY3JpcHRpb24gcmRmOmFib3V0PSIiCiAgICB4bWxuczppcHRjRXh0PSJodHRwOi8vaXB0'
    b'Yy5vcmcvc3RkL0lwdGM0eG1wRXh0LzIwMDgtMDItMjkvIgogICAgeG1sbnM6eG1wTU09Imh0'
    b'dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9tbS8iCiAgICB4bWxuczpzdEV2dD0iaHR0cDov'
    b'L25zLmFkb2JlLmNvbS94YXAvMS4wL3NUeXBlL1Jlc291cmNlRXZlbnQjIgogICAgeG1sbnM6'
    b'cGx1cz0iaHR0cDovL25zLnVzZXBsdXMub3JnL2xkZi94bXAvMS4wLyIKICAgIHhtbG5zOkdJ'
    b'TVA9Imh0dHA6Ly93d3cuZ2ltcC5vcmcveG1wLyIKICAgIHhtbG5zOmRjPSJodHRwOi8vcHVy'
    b'bC5vcmcvZGMvZWxlbWVudHMvMS4xLyIKICAgIHhtbG5zOnRpZmY9Imh0dHA6Ly9ucy5hZG9i'
    b'ZS5jb20vdGlmZi8xLjAvIgogICAgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hh'
    b'cC8xLjAvIgogICB4bXBNTTpEb2N1bWVudElEPSJnaW1wOmRvY2lkOmdpbXA6MjViNmYwYTAt'
    b'NTM1Mi00NDk5LTgyN2EtN2NlODZmNzdjY2FiIgogICB4bXBNTTpJbnN0YW5jZUlEPSJ4bXAu'
    b'aWlkOjcyMDJjNTgyLTI3NTItNGVmOC1iNDYxLTg5Njg1ZTc5MjM3YyIKICAgeG1wTU06T3Jp'
    b'Z2luYWxEb2N1bWVudElEPSJ4bXAuZGlkOmJlYzkzMzRjLTE5YzMtNDlkOC04NjhlLWU3Y2Jl'
    b'NWFlMmEwZSIKICAgR0lNUDpBUEk9IjIuMCIKICAgR0lNUDpQbGF0Zm9ybT0iTWFjIE9TIgog'
    b'ICBHSU1QOlRpbWVTdGFtcD0iMTYxMTQzODUyMzM1MzQxMiIKICAgR0lNUDpWZXJzaW9uPSIy'
    b'LjEwLjIyIgogICBkYzpGb3JtYXQ9ImltYWdlL3BuZyIKICAgdGlmZjpPcmllbnRhdGlvbj0i'
    b'MSIKICAgeG1wOkNyZWF0b3JUb29sPSJHSU1QIDIuMTAiPgogICA8aXB0Y0V4dDpMb2NhdGlv'
    b'bkNyZWF0ZWQ+CiAgICA8cmRmOkJhZy8+CiAgIDwvaXB0Y0V4dDpMb2NhdGlvbkNyZWF0ZWQ+'
    b'CiAgIDxpcHRjRXh0OkxvY2F0aW9uU2hvd24+CiAgICA8cmRmOkJhZy8+CiAgIDwvaXB0Y0V4'
    b'dDpMb2NhdGlvblNob3duPgogICA8aXB0Y0V4dDpBcnR3b3JrT3JPYmplY3Q+CiAgICA8cmRm'
    b'OkJhZy8+CiAgIDwvaXB0Y0V4dDpBcnR3b3JrT3JPYmplY3Q+CiAgIDxpcHRjRXh0OlJlZ2lz'
    b'dHJ5SWQ+CiAgICA8cmRmOkJhZy8+CiAgIDwvaXB0Y0V4dDpSZWdpc3RyeUlkPgogICA8eG1w'
    b'TU06SGlzdG9yeT4KICAgIDxyZGY6U2VxPgogICAgIDxyZGY6bGkKICAgICAgc3RFdnQ6YWN0'
    b'aW9uPSJzYXZlZCIKICAgICAgc3RFdnQ6Y2hhbmdlZD0iLyIKICAgICAgc3RFdnQ6aW5zdGFu'
    b'Y2VJRD0ieG1wLmlpZDo0Njc2ZTllZC1lMTEzLTQ4ZjgtOGE0OS1kMTkyZjdlM2ZhM2EiCiAg'
    b'ICAgIHN0RXZ0OnNvZnR3YXJlQWdlbnQ9IkdpbXAgMi4xMCAoTWFjIE9TKSIKICAgICAgc3RF'
    b'dnQ6d2hlbj0iMjAyMS0wMS0yM1QxNTo0ODo0My0wNjowMCIvPgogICAgPC9yZGY6U2VxPgog'
    b'ICA8L3htcE1NOkhpc3Rvcnk+CiAgIDxwbHVzOkltYWdlU3VwcGxpZXI+CiAgICA8cmRmOlNl'
    b'cS8+CiAgIDwvcGx1czpJbWFnZVN1cHBsaWVyPgogICA8cGx1czpJbWFnZUNyZWF0b3I+CiAg'
    b'ICA8cmRmOlNlcS8+CiAgIDwvcGx1czpJbWFnZUNyZWF0b3I+CiAgIDxwbHVzOkNvcHlyaWdo'
    b'dE93bmVyPgogICAgPHJkZjpTZXEvPgogICA8L3BsdXM6Q29weXJpZ2h0T3duZXI+CiAgIDxw'
    b'bHVzOkxpY2Vuc29yPgogICAgPHJkZjpTZXEvPgogICA8L3BsdXM6TGljZW5zb3I+CiAgPC9y'
    b'ZGY6RGVzY3JpcHRpb24+CiA8L3JkZjpSREY+CjwveDp4bXBtZXRhPgogICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAog'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgCjw/eHBhY2tldCBlbmQ9Inci'
    b'Pz64r5k3AAAABmJLR0QA/wD/AP+gvaeTAAAACXBIWXMAAAsTAAALEwEAmpwYAAAAB3RJTUUH'
    b'5QEXFTArE+TILwAAAL5JREFUWMPtl0EOhCAMRYthW/fchqN7G/fDAXDhZJKBiMX8CkaaGBNM'
    b'2udrxUD09jAH61Ex919MXRtY1k91Qu/mKgtqBr7wsWkLJBDqM3AGccsQliCsVtFkGBEt4MKV'
    b'va04QAaYiMIhRMmGlSXXiwlXnC/BngCEn1rvDHlnsmf5OhSgDIVoGXAfCMn9doD64l38jsEA'
    b'3BKAezDwQAArne59f+ds01nWePkLABoI2gZSE5jiYwi1T0aies0NjNgAV34zR89gM9IAAAAA'
    b'SUVORK5CYII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAABhWlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kT1Iw1AUhU9TRZGKiB1EOmSoThZERcRJq1CECqFWaNXB5KV/0KQhSXFxFFwLDv4sVh1c'
    b'nHV1cBUEwR8QNzcnRRcp8b6k0CLGC4/3cd49h/fuA4R6mWlWxxig6baZSsTFTHZV7HpFAP0A'
    b'ZhCRmWXMSVISvvV1T91UdzGe5d/3Z/WqOYsBAZF4lhmmTbxBPLVpG5z3icOsKKvE58SjJl2Q'
    b'+JHrisdvnAsuCzwzbKZT88RhYrHQxkobs6KpEU8SR1VNp3wh47HKeYuzVq6y5j35C0M5fWWZ'
    b'67QiSGARS5AgQkEVJZRhI0a7ToqFFJ3HffxDrl8il0KuEhg5FlCBBtn1g//B79la+YlxLykU'
    b'BzpfHOdjGOjaBRo1x/k+dpzGCRB8Bq70lr9SB6Y/Sa+1tOgR0LcNXFy3NGUPuNwBBp8M2ZRd'
    b'KUhLyOeB9zP6piwwcAv0rHlza57j9AFI06ySN8DBITBSoOx1n3d3t8/t357m/H4AcFBypsYq'
    b'MmAAAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAACxIAAAsSAdLdfvwAAAAHdElNRQflAREB'
    b'ASPlJhPfAAAAaElEQVRYw2NgGOmAkQK9/6lsHsWW4xOni+VkOYJpoNPAqAMGPBEO2WxItaw3'
    b'mghHHcBERoJDwQoKCgysrKz/sciN5oJRB4w6gK454P9AWs4wEI4YPo1SWpV6/wfScpo44j+d'
    b'9Y0C+gEAcUkibLR7Ba8AAAAASUVORK5CYII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERvIDE0IE5vdiAyMDAyIDIzOjMxOjQ0ICswMTAwhFAcSAAAAAd0SU1FB9MDBBUaLX+j7pMA'
    b'AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAAF50lEQVR42u1WbVBUVRh+'
    b'7t57dxcWl+VDBURJwQSFpETQEgrtiwIdP9KatJl0JmfKZrSssalmGsdq8ofTZE79M8q0HMcv'
    b'oiy/AhVBDEldHFFYFpYFgXVhd2HZj7u399xrAjX4/aOZfGcOZ+95zznP877vc84BuG//d+Pu'
    b'eocF5eHobV2IgFREbRoEYTQkSYYUsAGaSmj4fdBZf8KhD4P3lkDOHhEJhlXwdr8XlZQ0cmLq'
    b'BIxPioVeD3gDgN0ho6GhFY76evhtLRaEj34Xhwt23RsCr9ROQE/jD1HxCdMLnpqOaWM1iNQC'
    b'NhfQ2gM4fUAvxRsIARYaczv74Tj2qyz1i5tw5Pl3aAf5zgksr30Mjua92XlZsYvz4hEXBpxt'
    b'B851EqgfCBKon8B9rJfU336Ck3mg69AB2d8jrcfRwo/ujMBr5jw4m0qLih6PWJRpgI8AjlqA'
    b'Hp8aUyikgvkYAfL5qBReSSXCBCATWvvenSQQQy6OFJ5kW2puGfx1czpcLfsXLciPeHmaAV6K'
    b'9nADpZk219EuWoF6HRBGGpCDAQT7vRCoLHoaE8jHyyqYKTuXR8D96dAMLK8wQhQ2IsQ9Cp32'
    b'EL48uBZYG7oO/mp9JPob/3juyRnJS3MilcgOW2k8NBCZPyCjpvo8rJcafZCEOvL1UUpStCN0'
    b'o2ImpXPhCQnwEWkQKfve3XLII03FicXn1AyEvJsfnmBaWfxmVkbqSKzB6qdXD4med36dmZmS'
    b'PD8rEjyBnaADpqWVPNU1TAQ6O5zY82Npr9XS+T4MiXEoKXwEpYWz8MvceL9PO6vt+NHKzppq'
    b'aAmcMQ4fl8xBds8bVAI5d9UzEyHS1+K8h6hw3RuwpiFNcb3duHCEgVvyYl4y4klwFS1Q5jEi'
    b'DLyppQNHfjvehIi4HOya8wm+z+oeRF3GvvwKxGQ+4bpU97vLYoHASMclkkvKGSDA8U2d3R54'
    b'fGq9luVPCYO79RusqDbBad300uypXHoMUG2nZWwRgetoXpfTg6NlNXYYk2ejeLp5WP3sSvfB'
    b'mLK8q/aUT0OIOlMUK9/EAQJavuxEQzfCtaqSpyZFI238yGxwnoqMBxPHzXxAiyaKy0U1FDk1'
    b'A2yj3YdPBxCd+AK2TrHcVMT7Z1nA6Uo8LTYI4bSY05gGZQDl5+wuJT0Cpx6fpXmpECPC0uZm'
    b'J0NP4y10oWg51R9GRA9Uks443Wf4KqPilk8Sry3xttsV7RABboCAmFjVdNXjDQbV9LJBVuP1'
    b'i3KQYORQ7xiImpWo7Wof6i+31cMQ//HtXCMI+k/3O7vAKa9CyD1AYPOEPgjG09arXgWIoybL'
    b'auvuU6SkEGLRh5PwSqouyIgwrcMX4/tvi4AxtSHY1xuSvLRMIzSzIeG6U9SVnWntyZ0zifTn'
    b'U8qCkKwcdSVy9oP1dbYeONq7gtCKy7CyegWkkJ4m6oi1BfoRG7El7fzwYkzzyQX7XT5Hp4lC'
    b'N/+DQKjcfMWDgslqtPLghbJKSKIWFxWBJQUzRJ7j5mt4jeLgOBHtDtesgxW1RVhmnozvprQN'
    b'rwPB5W6zmSCIVUMJjEo8ecF+kcWuYwRCgxdd++boT2QYj4iESOXRCUrq4xMkgjHRsWiwxZka'
    b'W3tm0tTdwxLgOMnT3iYhEHlkQAPM3tB7wBtr2tx+5V5nJFhjouSu9azJBBiS1J59izSXXhdU'
    b'/dmCRuuVqxCjK2+oA57nZI3+FI4V2odmgJleW1bX4Z6ZPz6GSjuQffmaHpRToFEXMfd5qxPV'
    b'F23sNuyEOGIHjGM+x5ZU+w0JyHIYOGHb359DCYh8udnRt+7ZlBjlCWXGgNm5ZY0RaHb4ceJi'
    b'K6outfsh6w9AIxfDOboU+zJ8uBXTmczw9GwfVN1Btlk2iu6Ljm3zJgndXtXLyuCircsud6Ks'
    b'vl3udnNn6TwWIxS7HZvirtwS6A3s3/+QbGgufysrOjdrjAGVTR4cbLiCCzZnB12LO2CILcYH'
    b'I8/cLehNCLSko9exFcHgWBJABUn/W1jH/oyd8f57CXzf7tt/xv4CIgdcs5rCaNcAAAAASUVO'
    b'RK5CYII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERvIDE0IE5vdiAyMDAyIDIzOjMxOjQ0ICswMTAwhFAcSAAAAAd0SU1FB9MCGhclGYjr7WgA'
    b'AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAACRElEQVR42mNgGGjAiMzh'
    b'CdlW+eX7n0BhSTGd339+ffj15cPhfwLC03/NsT5A2AD3/X0G7voFnhaCjMx/GRj4ORgYfgPp'
    b'aSvOv3nx9V/hn9kmS3AbYLvSTsbO+gCfijQjM5ArDNTMDWSwAmXN5BgYFmy+/un++x/xv6ca'
    b'bcBugOOyZcqJkZHvL97//fXN0yOM/xm+ConzOjjZ6fOw/WdgEORmYFi8/ez1V584jBg+P/3H'
    b'q6iy4+/vn1e/dWvlMoH0c0nLWn259+7/u6sPgn8utHX6scjW99krBu3t+8484+FkYPj3j4Eh'
    b'0sVAU4TnyzoGVtaSubFKjirCjKkgvWADWLh5xD4+eXaaYYfTZrjbFho8evuBy23vmTu/OFgY'
    b'GER4mBnExQVtrI3lqkHufvft52O4AUyMjL9/vHl1BCOE5mtfvff8w9Z/fxgY/gNdEWSqyptg'
    b'q8z17jsDw9vPPz+ALQcRvz6+fcDwn/kpSpQW3Sr/8v2r5vfXb/5sPH2DId5eA6iYkeHzTwaG'
    b'159/MDAy/n8GN+Dbm9enBFUV1d7DdEe8ZTdU+t5a6afK/Bwo+AfoAmDAMnz8wcDADtRx/dkn'
    b'oINYLsC9IKwq8RpoJBPc+hXCP8/e/zY9f+HtT+vPv2b4CjTgCxCzAKOWG2jAtfc/vzP+/3sO'
    b'bsDbA0wN3AKcL5C98K1XLff2C1apfZdeTOvYdff+mjOP/gsCY0SUB+iSn3+ffu8334iRlPGC'
    b'qrvWfIwf26T4uUze/2Je+bJGNYnsDERVAAAJF+oOQNYRZAAAAABJRU5ErkJggg==')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AFNvIDE3IE5vdiAyMDAyIDE5OjE3OjQ2ICswMTAwQcC18QAAAAd0SU1FB9MDBBMmG8dnfkcA'
    b'AAAJcEhZcwAACvAAAArwAUKsNJgAAAAEZ0FNQQAAsY8L/GEFAAAGaklEQVR42u1XSW8cRRR+'
    b'VdU9PUuPZ2LHy8hJSOyAEk4gIQQoIgQkThy4cAyIA0ckIggSBxAohxzggsSFE5xAQiKIE4uE'
    b'ULhwYseEYMA2AaGEeDL2eJbeqnjvVVdnvP4BGE9NVVdX1fve97YywH/9I9zgxS9+C9640Duf'
    b'CvNkPzLNR45m8NKJBPopgBSClxpjIMs0aJNCmhp8pj4DneE8jjMcZ1kGBluKc9pk4IsM3lts'
    b'woXLdaiauOOb5K2nTx174dxThyOS6zkAb344OH/j6uoZtbwEWZyC9iag9dgdMDlzCKQU2NQm'
    b'5ATGaI2CrNA0TbmnliQJ9imv+fvPZWgsd2B+ygfle82lXztnXv/4W1QLnt8EYKjNabWyBELi'
    b'Q8kjtUEIS5DWBgEA9Hq9AoBG4dRIMAmi3j37vs9MMVDq8KzetctQDnyYOzoHK99deWIbgHIg'
    b'9w+IaBJsBAtkG4nCSrC4uAjD4RDfye22zNcRmNnZWV5DgAxYMfG1RVDlElRmboNQmalBvq8A'
    b'QBtZOG4kAPjlA0YPr9frEARBMcdmGGk0RyZw726enUHtyD1ILM7TH5oItgLgQz3Jm61A1NLA'
    b'poPm5+e3ae7s73yA7B/H8U3wuXJ+uB9NQw8ZwI4AUA7Rxixo3CbQs3VWHETvlpaWWBABZHpz'
    b'rUdZoPlms1ms0aSAsWtxNSjrQLswkJvAWdg5Fm0mAN1uF6Io2tH2bkzrG41GAbxgkCKJQIys'
    b'3wZAKsVR4MxgtLFxnWs6PT1djB0wmxuywhzOB4pQRe3ZoEQEHq6E3BmAdUJgBogmJA9jPN0E'
    b'gByQBI8CoF4hcLfGeb8DxWuoJ2YF7pFmDwbYCWWRH91B7vCVlRV2MLGFxq1hODExMcIAv8Sv'
    b'pV+ZPUwghDWBIgQUUi615gBIU59debtwx8yoM7ISZBLkQDqz7mYC6wPWBCIPn9EooPBqtVqF'
    b'f4z6gGPKZcdR+hkEjRWaRxhmYncGPM/aH6UrBJrGA+h22pw82DRgKR0FQHOjwnWmizFpEQ96'
    b'eBZFlk1uxCyY3RgQLlwErA4MfPRNB+KkXYSOzPcyJ8aypEkrbXsqTgJycMKC9XFhOx7ngkbH'
    b'CCX3YkCy/UnQpesSfryogI9E7aWyTsQmUFYjoUSeO5T1ETf2gHuVv/ew96XmfewHOwIwRLti'
    b'tUgzH398z6K2PjmSpp02MgcgbLW0z7ropXtPL6ln5fZggJ6IAZOjEHk0aIyOjGf5CBvvHPME'
    b'Rto1CF4q6zwFMGmsU+cgiTGzuxMazFI5A4VwNgw8MP47rixhnsBLBc5lJuN6T6k6TrAQJREk'
    b'kYYkjjB5JeiIKXTVOPTLLU4+dHZpah5N4jOYHQEwMA/txj6f047aJijk7KNH4PCtx6HfvQHd'
    b'9XW40W5Dp7MO1zsxBJUQi88shGEdmlgDqGTPzkzCvY+/DIP6HBKUcUG663AdfrgaW4feLQqs'
    b'eSzRzvb0s97twSdf/gGnX70ME5MhBPUymOo0nDtxDaphCKVKHfxyDVRQBVmqgAioNaAyNYe7'
    b'E0gRwLHWGPz0zypkuxYj9mLFycICtCA8DEm6BfWHfUi0giijCwv6ROZDI2yg5lVsYdGIARA+'
    b'1xLgGMozIvcStmbxmwAw67F9hA1DB4qcZ2OjB/2kBuUmalvzwac7oy+x7IbQGAuhWrPCx8bG'
    b'oFqtIsUJV1IOU0NNWlbZMfOQ2wYAU63n2UJkC4j1AYn+T5fRge5DdV8TbY4xjXc77XsQ1gPU'
    b'2AIgzUk4rRVZbNO5zIVrYXOIFHlG3YGBLE6utLU+ONnwGIADITGrrKPjReUJKI+VsSQjALzd'
    b'alVirWskHDWvVCosnNaaZAh0HaWrvMiZZTaUKP7HKLKvG9x5/ND97dVk4Xo7wvs7ZTPFB1CJ'
    b'zjASSBhKQ+erQFYuQ4Z3gxC1bzSs8I2NDVhbW2MA6911a8E8J0jOhJJrAtWKONXtbQx89syB'
    b'5dvP/vLQpYVLn5s0Pd66ZdwygRu8UgBzBxrwypSEsbACtWoNPGyzM/s4KUXopDFe1ajRlU1j'
    b'ESPVVOCBxP0K13x1FeexX/j0e3Te4J2uczPY8jn57ELr64WFd5MoOolQsSIm8Nypn2F86iAE'
    b'WC39EjohJiQPfcBg4qIIsS2CwXAA0WCACWoI719cg7/kfZhXUvY59EmqCYNSIN9+8O6DZz54'
    b'7eEI/v/g518C+3noLhkeJgAAAABJRU5ErkJggg==')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AEZyIDIxIEZlYiAyMDAzIDExOjE3OjMyICswMTAwvynnCQAAAAd0SU1FB9MCGA0OEUv4dh4A'
    b'AAAJcEhZcwAACvAAAArwAUKsNJgAAAAEZ0FNQQAAsY8L/GEFAAABY0lEQVR42q1Tv0vEMBR+'
    b'Se+i0MXNsbuOvT9FHBSlR70cIji4ODq7iKiDZDoUVIqODnKLiyDYelMXf+zicA6OvbYmqalp'
    b'LHqgH7y+lzTfl++9UoA/Aqlitz8MiW272WgEv8VrHEd72/OtUmX/+j2MX9J8XNw/DPP1zSAU'
    b'3IZ4WIS4M9MYrp4BJvnOhAirqBuYv0dFVph1bJhyHLcUELYACPQDJokNHpiTltoUzo+ZrC1N'
    b'YK3jQZ6mYAgAzC1TsJufLqzCid+hhagmgPKk5FQELk+ZPCgI7RUKZz0m3YgWMPoS8H2/XmDB'
    b'K26zCXfBc7dLpRsTfI71Ahe8X8KJTR4ya7YppcAYK+usbgbCgbhdzUHvWxEVKg7SJJGL4IjJ'
    b'wZm3mxBCilMRMB38hEwXUIuT3ncHeu+6A3OI0eDxzd1Y9YrvjBBgjGWYvQvc3D6JFMmzanPr'
    b'8C7Ms2ysn0mQD3YWW/Af+ADDIemRfOJNcwAAAABJRU5ErkJggg==')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAABhWlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kT1Iw1AUhU9TpSIVRSuIOGSoulgQFXHUKhShQqgVWnUweekfNGlIUlwcBdeCgz+LVQcX'
    b'Z10dXAVB8AfEzc1J0UVKvC8ttIjxwuN9nHfP4b37AKFaZJrVNg5oum0mYlExlV4VA6/woQf9'
    b'GEWvzCxjTpLi8Kyve+qmuovwLO++P6tLzVgM8InEs8wwbeIN4ulN2+C8TxxieVklPiceM+mC'
    b'xI9cV+r8xjnnssAzQ2YyMU8cIhZzLay0MMubGvEUcVjVdMoXUnVWOW9x1opl1rgnf2Ewo68s'
    b'c53WEGJYxBIkiFBQRgFF2IjQrpNiIUHnUQ//oOuXyKWQqwBGjgWUoEF2/eB/8Hu2VnZyop4U'
    b'jALtL47zMQwEdoFaxXG+jx2ndgL4n4ErvekvVYGZT9IrTS18BHRvAxfXTU3ZAy53gIEnQzZl'
    b'V/LTErJZ4P2MvikN9N0CnWv1uTXOcfoAJGlW8Rvg4BAYyVH2use7O1rn9m9PY34/WhNynXF0'
    b'SXkAAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAADsMAAA7DAcdvqGQAAAAHdElNRQflARAV'
    b'LiG6pyZXAAAB20lEQVRYw+1WwZXbIBD95O1ddGBYFxJKoROrhJSgElQC2wEqwNG4g1EF5LAe'
    b'h1WMBY42uey8x2H4An2YPzMAK/PeJwCfNq773+wb/rO9lABjHIxx2QwBIGitobUGM4OZH2xt'
    b'ruO6mgKIQhsB507ZzBuAAGMMvPdqGIZERA8IOADfb14IaCMgpjVD6yU7FTAMQ1qfXm7mo13A'
    b'3IFZt4fg98YLvDdK/NLJtdbw3qv1/DBQeooAUUAI7zeQK3ccx7uxvxJI6/lx/AFmfff6NwmU'
    b'Fv2TLHDOwTm3249CCAghtBE4nU67nvYegc1CRERQSqlpmo6XywXTNB1zX/TAzMjxxynaQMBa'
    b'q/q+TzHGszFGxRjPub8s7ym6LAty3Fqr/koDYvM8J2utijG+ElFi5qP3/qf4XdcBALquQ47P'
    b'85x2IWCMQUrpttnhcDhn7h+FqIQ/HYK1BiTmJW1I7AXf0kKzBiTmJW1I7AXf0kKzBiTmJW1I'
    b'7AXf0kKzBmq1UVpXTeBe0di7CG0S2JvEVy/YtReIrfO+VBeezoIs329vwb7vP+AppVT6TvDd'
    b'e0GO19SFT+8Ftd81a6C2J0isW98F1QS2eoLU/NZ3wUstga2eILFufRdUE6jtCa3vgq9e8Au2'
    b'7DRA5e6QQgAAAABJRU5ErkJggg==')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAABhWlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kT1Iw1AUhU9TpSIVBauIOGSoThZERRy1CkWoEGqFVh1MXvojNGlIUlwcBdeCgz+LVQcX'
    b'Z10dXAVB8AfEzc1J0UVKvC8ptIjxwuN9nHfP4b37AKFWYprVNgZoum2mEnExk10RQ68IoAd9'
    b'CKJfZpYxK0lJ+NbXPXVT3cV4ln/fn9Wl5iwGBETiGWaYNvE68dSmbXDeJ46woqwSnxOPmnRB'
    b'4keuKx6/cS64LPDMiJlOzRFHiMVCCystzIqmRjxJHFU1nfKFjMcq5y3OWqnCGvfkLwzn9OUl'
    b'rtMaQgILWIQEEQoq2EAJNmK066RYSNF53Mc/6Polcink2gAjxzzK0CC7fvA/+D1bKz8x7iWF'
    b'40D7i+N8DAOhXaBedZzvY8epnwDBZ+BKb/rLNWD6k/RqU4seAd3bwMV1U1P2gMsdYODJkE3Z'
    b'lYK0hHweeD+jb8oCvbdA56o3t8Y5Th+ANM0qeQMcHAIjBcpe83l3R+vc/u1pzO8HCityffgL'
    b'IvEAAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAADsMAAA7DAcdvqGQAAAAHdElNRQflARAV'
    b'CAbccxAYAAABSklEQVRYw82W4Y3DIAyF7YoBGMUjMIpHyAYxGzACo3QERmED358Q3eUaJQG3'
    b'qaUoEiDx/PEwBjgIZlYA0OVvHg+4OU4LKKUAM2tKSW8TkHOGUoopAXd2YQgBQghQawVmViKC'
    b'aZrwYwRCCDDPM3jvTUlcNqGIoIiA997EE5cFqKpakui+hlYkugVYkRguRKMkhgWMkjArxb0k'
    b'zAT0kjB/jK6SMBdwlYSz2hgRUUTWbJ/P559XdO/tcIboVURevqKLCFsCLWMRQVVdMyciIKJ/'
    b'61+NDQloGf/G3jbKOePb6gAiYoxxPePROuCszrodQ4wRUkq7Z94toGW8dETreK0VYoyw9YJZ'
    b'tLa8fdv2vM2LiKqqLp443caf9gARATPvurnXC+6KgDPuvuqFx2jmbb55ARER7oheLzhrIdvb'
    b'cuSZj92WtxNoXjiq/V8XP/W1H4e21fP2AAAAAElFTkSuQmCC')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAABhGlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kTtIw1AUhv+mSkUqInYQcchQnSyIijpqFYpQIdQKrTqY3PQFTRqSFBdHwbXg4GOx6uDi'
    b'rKuDqyAIPkDc3JwUXaTEc5NCixgPHO7Hf89/OPdcQKiXmWZ1jAGabpupRFzMZFfF0CsC6KOc'
    b'RkhmljEnSUn4xtc9VVLcxXgv/7o/o0fNWQwIiMSzzDBt4g3iqU3b4LxPHGFFWSU+Jx41aUDi'
    b'R64rHr9xLrgs8J4RM52aJ44Qi4U2VtqYFU2NeJI4qmo69RcyHquctzhr5SprzslfGM7pK8tc'
    b'pxxCAotYggQRCqoooQwbMTp1Uiyk6D7u4x90/RK5FHKVwMixgAo0yK4f/A9+79bKT4x7ncJx'
    b'oPPFcT6GgdAu0Kg5zvex4zROgOAzcKW3/JU6MPNJeq2lRY+A3m3g4rqlKXvA5Q4w8GTIpuxK'
    b'QUohnwfez+ibskD/LdC95u2teY/TByBNu0reAAeHwEiBeq/7vLurfW//1jT39wM3E3KPaUPo'
    b'wQAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAALEgAACxIB0t1+/AAAAAd0SU1FB+UBEQIL'
    b'Onnk7cwAAABTSURBVDjL7ZIxDgAhCAQHv8mDePZa2RA9zGlxxU0DCbBsCPAVlHJN6qqGqzil'
    b'LZoE2I71IZCbrdqcBXhwYOkG2hVfEhEC5O6yY7VTB29/RvzcowO+piA+6LC3hQAAAABJRU5E'
    b'rkJggg==')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAKnRFWHRDcmVhdGlvbiBUaW1l'
    b'AFNvIDUgT2t0IDIwMDMgMjM6NTA6MTAgKzAxMDCmmQ8LAAAAB3RJTUUH1QgQDgMk8/6hegAA'
    b'AAlwSFlzAAAK8AAACvABQqw0mAAAAARnQU1BAACxjwv8YQUAAAcZSURBVHjaxVd9bJVXGf+9'
    b'X/e2t/Tjwm1LOyobjtGBVIhIddEQOxAymWPMRFrn1mH/GKQNf5g4VGbMyP4xMEjKEuNCtimJ'
    b'kxnIssSohc2pgAgaiWuCYPlowfXzft/7fp/jc877sgLtxdvEZO/t6Xu+3vP8zu/3PM95X+AT'
    b'vpR7jf2IruHh4add1z2jadrriqJ83fO8f+i6/ivO+RcNw7h2+PDhq4cOHVJ7e3s5PcP/bwD2'
    b'7NnzdDQa/fnFixePOI7zeENDQ20ulxu3bbs+kUgkLctKFItFt7m5+Tjdv2qa5hgB2x+LxTry'
    b'+fxHBPgggdxMfdmhoaG3BgYGvNnsaKUANDU17r1x4/rY0aO/fuLhh5fdn0wm15hmYSVjvp7N'
    b'5r5i29Y3iRk/m81uI+O/JJC1xNDzBMyg9peJne/SBjalUqmt8Xj8MxcuXDhaNoBXXjnzciSS'
    b'+EZLy9rmZ555udOyiu0jIxeq1qx5Nq5o6mfHx68sampadZoxp6pQSH+ewOzVNPVmoVDcaNvm'
    b'Ds7ZKao/kcmkv0VzjjmOt6etre3k4ODg8N221NkA5POTnRs3PlXX07PVeO65B9seeWRpYmoq'
    b'ha5vf+3ZJ++Lt6fSWbS3dxxYv37HzkwmidbWLUeWL+/6caGQRUPD6t2LF2/Ybpp5zJvXsmnl'
    b'yl1F0yyaxaLZMZutWQF4HoNh6JKh8+fP4qWXfoDHHtuMFa3zceRP7yJeF0dPz3po2iDS6TwO'
    b'HNgR6+xcXT0xMYmursc/R2VtMjlFIL/UvWpV8zvkI7GamgcfLRsAOQ983xd3ZWoqifr6Buzc'
    b'uRNH334bf7h8ExQcOHHiBHbv/iG6u7djdHQc27ZtxbJly9HRsRYHD36fwEWwa1cXRkYGQFIQ'
    b'M63lh8aLLx6/8v77eX71qu0QCH7t2jU+OTnJReP085v4eDrLabd83779NDbML1/+N9+y5Ul+'
    b'7tx5furUWd7S8il+7Ng7/MMPL3FyZt7X9z3+wgvHP5jNlj5bJ20ejDGih8kwXdS8EKqqypht'
    b'q6uEUVuNCNW3d3fTTlXU1NXh1f5XoesG5i9YgIHfnUR1TQ0SiQa89rM3sbDpAbzxxmmUDYBz'
    b'Xxq7lFe0oTFq+xFq0y8KtNP9XAowHBFCcagENjJBc/R6GVKFHD1Zex9MVUHaBla3r0NyIkU+'
    b'FS0fgEhoHtHwUBXzFjfCuJWvRCbRyeLKOOCaVHyF5gEOozFVh0P1NAFzWSVsjwdzWAUKdhya'
    b'ivIB+D4H8xkYZ8qMyZ6HGgGRNFBolDPBWFBkO6yLhhgTfZOTHv7ozQFAsADHmAmlkIIkQBWG'
    b'KoClFKJXaGe6FfAiiobpuhoWRQ0WFzs3PTHG5uYDIgyrdY5F84hiWsAXNNOuVaroagDSJcrp'
    b'T949FhQxzxV1P3yG5tk5reQxVZIBn56uUDlqyQOEF8gNqIEnfDoabDtg6k4Zbm8roYBSgrky'
    b'QHGIUVNRrLT0SShi0UqSgLZ3lSRQzZn0f9xWAqyirtE/2wvBlQ+AooAAzNMZmiqnJXB1AYRJ'
    b'Q5JuHt796bagv7FK4pdtJv3BwIb1K5r6+8sEILYsElGUJJhPdPtasDtGs3XuYQmB4upd3n8b'
    b'7SrNj7w241VjadkMCPQCgMe44ofOxXgAQKMOU0AMaeWYBiLminZFJFjnWG8vCszC7wcH8YsP'
    b'zsxNAk4ApkyOsxOBR0sDFIZfID3OUJ9mBX7h82kAlPwkUBE54kp7ReRNE0XXQamrJABGJRHl'
    b'WNFARtyAWp+iwSCr6+rJmBUwJQzTEfAxiDAQ5OXTBJ86HdebKwAmJaDTOIgAJTQm9QnOCaE5'
    b'bst+s2iOgmXBdhzMj8WCjv67skEflHtI4OM/JkNyPPQBksEmCdbZHO+NkuFCAEBIsLgmeO54'
    b'bx+m3Lw8R0zbRpGMi/qyxkbs63xKAhcG/z4ygjf//NfSDMizgBZuqlTQuoCMhwyKPFCheNiw'
    b'kCQoTnu+ZoQ75pbUXLDn0JkhjDMqrng2eMFBhI51V8Tt//SB4KVAJhMW6spvhQim9RedLCT2'
    b'7NAQsgTApcGYYWBJIiGNj+VyuDQ6ighlJYMA3MxkygBAi4zZimLSYWR5QYKxo0IChpNjgQS3'
    b'ANwfStD/2/fuWGc/0S42MjQ+jhP//NfcokD86igTPlQNeeLI93cKr5ji4lGKDOSmE5CQwPoO'
    b'vyMSql5XgmigDv3Wy0DfzA+he0gQ0F+hBU4ojlcphYgOke30kIGwn9921ujhqjohDGgv+f1T'
    b'KhUzGcMqIXccTt8JJgoFB0VuoKJyCW785SNYqTRM04ZlOfIuSqEg7g7a2hbJdPC369elM95I'
    b'pUoCmPXbsKfnp7+hXLBCVY1KVdXyjPEMbSTDoWQQiWYU103TC0aGmMooipohrBlVlW06O1l2'
    b'795tm+vfqvnJjIX77vkx/Mlc/wUuxQSZPx4QZAAAAABJRU5ErkJggg==')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAKnRFWHRDcmVhdGlvbiBUaW1l'
    b'AFNvIDUgT2t0IDIwMDMgMjM6NTk6MDEgKzAxMDAwUS/rAAAAB3RJTUUH1QgQDTkaFXDc8QAA'
    b'AAlwSFlzAAAK8AAACvABQqw0mAAAAARnQU1BAACxjwv8YQUAAAIjSURBVHjapZNLaFNBFIb/'
    b'uXNfeUAMkURJKqKIJrabaqHqQlxYWhXBtRBcSKAufCy6kK5UBDcWRJAoUsG9WyvougRc1JW2'
    b'+GiVLhRqTFvb3JvcmfFkUjEXEjcdGObe4fzfOf+ZGWCbg3X+lEqXs0qpZ57nBzR+2LYjTdP8'
    b'wBiWaa9G3xuu61bK5XLzr8bsBCQSw/dTqZxZqUwXksk936QUX1ZWls8CwX7O+VvH4eu1WvUM'
    b'hd7sCsjl+s+PjGTs3xuH+NrXxezxcxePff74HgsL88jnh/sYczZnZ2d+9gT4vodMeie7fuMq'
    b'Ps28gJdxMVA4TYC9eDc3hyNHB6NLS4dlpyYEkEJglcfBI3Ec2J3F6tBJiAaQT/fj4IkLMCxg'
    b'fvGN0RMQECBmKNgWg60aMEmgox1aFeDaQMwM9T0MEASwDKaDhZCoBwT1Ac4Bm6ZH1QwO7bN6'
    b'W5AC1bpkBjMQ8wOsk0ARJEmS1DRlbrkPEAIY4QokIlxRmVS1kthBoZkYZWFaiAelol7/Y6GN'
    b'dwhrKkG9ACKPWFtE2elyAVQVbkHpvTtgIYCSCr8owCDfcU/BDLYyXylqse/7mCyO6l7de/K6'
    b'2ykEcCgha00ZQFEzWxmvTT3XoMlLo7j7+BXQusjNLhaoBkQdzuJRskFHJ12yNaE0yLzN2hY8'
    b'Cpv694ZChzo+/vR7X25Xiux6bK3qbVpxr9lo1sfGBhKnXhbSOqug+TCs29b4Ax6q1zvJMoHc'
    b'AAAAAElFTkSuQmCC')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERvIDE0IE5vdiAyMDAyIDIzOjMxOjQ0ICswMTAwhFAcSAAAAAd0SU1FB9MDBBYAJcMTIiMA'
    b'AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAAF7UlEQVR42u1We1BUZRT/'
    b'3dcuj2UVlkUFVuUhYZohkU9SCBXNptFx0ho1x6nx1Zh/ZNrDHjM65eRk5l/Zy2xyRp0pIg0n'
    b'J01RAw0DCkJAHj6QZWGBfcA+772du5flMRpS+ld5Zs7st3fvd87v+53fOd8C9+3/bszf/7SD'
    b'RbYpF6K8BJI0DQw3GhzDQoYZPFsCTsiHn83Dqafd9x7A3B/nwNu8G8MMD+mTxmNsUhxiDCHg'
    b'OMBuF2FtNsNcXwf7zZYmRIa9iUMLv6RQ8r0BMKdgM0THzuhZOdxjaQZMMKih3T5AYAFDGAJA'
    b'rjuAkno3Lp0vkp2drT8hwrQCX82w3B2AnII1YLs/Tlm8hMkcA1zrAJookUwAQnhAS4k15AJ5'
    b'nA5IJnAWD3DqfC2qSv9sQFTyAuyfWP3vAMw+Pg6ipSxx6fKwJAOHylZKRicOF9TE2h4AirP0'
    b'nKOdLHlMOKAjVi5VWnD29IVmGONnY1967VABsL0ryb5dnzYtTB/OocKinjRMSwlD6PShtKbP'
    b'UHKBgAiUmGfVdxzEQDuxNCklBtk5U0bB2lSANXXR/4yB6fnx0DjqE55ZLvg8ahJGkmG7Ugmn'
    b'+Qa8rm6Z5XkMj4lmklPHYUyCEbJPZYAjIHwPoHACWlTWgJKympPQ6nKxP1MckG1TzVy47QsR'
    b'OuwC9ow7RE9klQG2bVHY2CRBpFrzRLnH2or6o4dd1rrGDzxd7FRZ0BhEhJisna5nLxSeunCi'
    b'oDBQBo2glkIBoYDxeYGsjATExkfnQKN9dUDyjZfTOY/l2LxHTJsMvO0g1v76dj8GPjscNWv+'
    b'0ghTHERnF26cyLNClzAH32eW3UqazGDVia2cxO1YtiibC9WyxJYKQgGj4dWgHx4544F+dAY+'
    b'TKzA1k4B5ksX1z81OW3NzEjkk0zf+eJUCw7kjFQZkJGqjTKC15CqLxbK1FJrb588gFnGgdyd'
    b'osaw/ptjZyWFeqVkQSagdAzFeXLGg1q42j8KbOlq3JKSNCJt/qRIHL+iCplQin0iZJhRgk4D'
    b'T5sDXoerAvlZ395RPZ9P/tQjanYXnClDqEbVQRCE5AemphoRGcFk46XS14jWbS/Om4Dym4BS'
    b'5stN1N88V9QPgKQRqJ7OpgaKoD2inmMIFtv8+vVrbSU1V9ug7Gd7WpMh95NIF09LYdDR9u6y'
    b'zAdCfD0RlWHW0GpTEJ/r14acX9nosVL/sVzhUFsIO5f4YDSt/aG4yq8Mp95SkJMskDJSh8Xz'
    b'0pGREB2YpMpzhf7aVruSpx8ABq0yKdhjtytD9/KQASi2N/U3mQk5cOb3q4HBFWBBEST95KVS'
    b'TEmMgl/qA6ZYs81lBxdbrqx5FQDb4LPbUyWPx4WkBOsdk26o0ENyxlK5XHC5XRDte4squlc8'
    b'/vAYbaAl0VcOWeori8LQ9Y5uWugvYk+ir48Bjil3tZqph3Q2fDJdHDT5uj82o/OmWcuIVYLf'
    b'2cjwPjNYvhQ+v6a00Ura6ksePHXwuyLU2habMkDOBcOpDLD8L87m68oUGvxuX1eephE73t++'
    b'cS6TFAW0OEm4XjA+kXqTiidJqnxZ5lZnemZEjbVLme9nBwIIlQq7re1uhOj9gwJwe0xRxnBm'
    b'nBE4Tw3j8asXFt/PuR4N9C9DkA2lA6ptLi98povBkGoJClbaIISfppVmUADd/Emz2Vq2YV8p'
    b'6qiXdXQ5aQU1MQPVg6cNei/99E6zg5TO6cvwXohzIICACQepNbSDAjiS3g1n7DRzl7zyu3PV'
    b'Z3YdOi/9XN4ID9UgXKtSzLJ9QAacnrRxmQYdDYxz/UPyvSsNnwcuPOuOHZA3ke5LfK24+HJ1'
    b'SnGdbXVx5bVVcXGRo2alxiNjbGRgGgbUjz4ASv9Xtbkoj3YAAOaOCYdiWzoE+JuegCS/ANaT'
    b'OzPZKMxJjYUpiu8V5nAq13NHayQ3FxeLV3Qt9xZAf3urJR7e9lVw2VbHGCMSF4wfxWQmRKLK'
    b'4sDuElsJtpkevfcM3M520X8NS3EWZO3zREEWDQELIuJW440RZXcf/L79l+wvBAcRVtqAmzgA'
    b'AAAASUVORK5CYII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAAXNSR0IArs4c6QAAAGxlWElm'
    b'TU0AKgAAAAgABAEaAAUAAAABAAAAPgEbAAUAAAABAAAARgEoAAMAAAABAAIAAIdpAAQAAAAB'
    b'AAAATgAAAAAAAABgAAAAAQAAAGAAAAABAAKgAgAEAAAAAQAAABCgAwAEAAAAAQAAABAAAAAA'
    b'yJjDqAAAAAlwSFlzAAAOxAAADsQBlSsOGwAAAflJREFUOBFjYEAC////Z7G0tHzi6ek5C0kY'
    b'L5MJTZbxz58/Px49euRXWlqaiyaHlYtuwP9///791dXVFf/48WNNXl5eLtBVjFh1QgXRDWAA'
    b'GsDg6+v7Myoq6sGnT5+qgYYk4jMEwwCQwX///mW3t7c3i4iIePjhw4fWwsJCkCFY1bJgcx5Q'
    b'MVjY3d3dGMi+smTJkrbi4uJ/QPYiRkbGf8h6sBqApIDZw8NDi4mJ6frixYs7ysvLgWb8XwI0'
    b'5C9MDVZnwSShNIubm5ssMEzePn36dArQJZFnzpxhhakh5IIPQIU/U1JSPr19+1br1KlTDMrK'
    b'yos5OTm/AsXXgwzBagDUn28zMjLuxsbGCj5//lzu+/fvu4ABe4CFheU7Dw/PZZBmDAD0H4ux'
    b'sfHNmTNn/qyoqLipqqr6f/PmzR9v3bp1EmjQV6BL/NE1oYcBKNH8nzJlCtubN29eW1hYpEyd'
    b'OvUXMD0IfPny5RfQFVpz587lRTYE3YD/wsLCQrKysse0tLQyFy1atBCk+dmzZ2J9fX23gOmj'
    b'9dixY97IBqCHwV+grfG8vLxPi4qKLsvIyLDZ2tom9vf3TwSGvhTQi4xAV8BjANkgnOwjR47w'
    b'AnPoHzs7u/9AQyZNnjxZClkxuguQ5cBsDg6OHw4ODs6fP39mVlNTu5Senv4GWREA2WTcD2vq'
    b'MgUAAAAASUVORK5CYII=')






from wx import App
from wx import Frame
from wx import ID_ANY
from wx import ScrolledWindow

from hasiihelper.UnitTestBase import UnitTestBase


class DummyApp(App):
    def OnInit(self):
        return True


class UnitTestBaseW(UnitTestBase):
    """
    This base class is meant to be used by unit tests that need wx.App
    instance opened.
    """

    def setUp(self):
        super().setUp()

        self._app:   DummyApp = DummyApp()
        #  Create frame
        baseFrame: Frame = Frame(None, ID_ANY, "", size=(10, 10))
        # noinspection PyTypeChecker
        umlFrame = ScrolledWindow(baseFrame)
        umlFrame.Show(True)

        self._listeningWindow = umlFrame

    def tearDown(self):
        self._app.OnExit()



#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERpIDE2IEF1ZyAyMDA1IDEzOjU3OjUwICswMTAw0YaYRwAAAAd0SU1FB9MIDBEFIpcrTL4A'
    b'AAAJcEhZcwAACvAAAArwAUKsNJgAAAAEZ0FNQQAAsY8L/GEFAAACR0lEQVR42qWSXUhTYRzG'
    b'n3c7Z6sjqWVmGPSxtFBDIrIyjbJAIwj6gHYVMbEvDboIDCqEcgR1I9FFWyVDiqJyfpSSRVTe'
    b'zKNld7kPRIvy2DbP3HGb8+yIb0fDumizQc/Fn/fi/f94n+d9gP8UmT+IY372RVt7bWhaOcmk'
    b'LF0dkcYnwiPDLZTRXblabxYWBHjcbobn+Y7lhUUVGzbnYSToQHB6J/zeAB3ttAnRgK/0+o2b'
    b'X+IBNLPjA99Tk1awtaJUXdbCg90PS5CuuKBhOZJ+oHqVXqe3JHrBHECMyKbsgnx4ZzzwS35w'
    b'Wh04Rsa6FYMgGgaMYUv56arK7HgAZnbQlNQcKexA0aMSLGZ0qjGKXc+KMDWmoLWyG3LWWiKN'
    b'j69XrwpxAbGQJI6Ei1PeGPuQSljssW/H2yO98CkyBlwZQEgAIURMaCEsDHWIYwEMePMgMQwm'
    b'/bFfy99zsSjLgIjHMfi4ucWZEAAtWx9+1zQ6EdPQ3iEDnp7oRv/nZWC5NEx+bKdywLvydtOT'
    b'18+PFXMJe3DpYm2uTs8+IIYd2/SZa6gSkRB1vv8xMfqNNTdYM/vvn0PZy8Y2MjRlJC7E/gLM'
    b'60yVqVAKBnPkmCI6evt6Lly+ZtlIXaaDeyXAqcZg5zvB+46Sr5CTqurZupq06TLYqK2cUs95'
    b'SpsPUWrMeEXzwSUFmPtmNSt6eMk9enefCqmmEftxWtdgdf8J8R9Sfc6gNXQKnQ5LtMsNX+kt'
    b'kJD46XcPkoRQ2h6tNpfs36S13hkOeIXGpC0spJ9CUvihw/jnbAAAAABJRU5ErkJggg==')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAAXNSR0IArs4c6QAAAGxlWElm'
    b'TU0AKgAAAAgABAEaAAUAAAABAAAAPgEbAAUAAAABAAAARgEoAAMAAAABAAIAAIdpAAQAAAAB'
    b'AAAATgAAAAAAAABgAAAAAQAAAGAAAAABAAKgAgAEAAAAAQAAABCgAwAEAAAAAQAAABAAAAAA'
    b'yJjDqAAAAAlwSFlzAAAOxAAADsQBlSsOGwAAAslJREFUOBGNU01LG1EUvZmZfBiizQcR4kg0'
    b'qcagBEpETAJSRGkx0CzyB9wE+kNc6i4UqS214KIgNHQhFHRVKoIkYrsoqUVDSU1UiIlNzPdM'
    b'puelOJC2iz54k/fue/fcc895IcJQFIULhUJJtvyfOTg4qMRisTDLFdiHDVmWyOOJkNv9kHj+'
    b'K2buhyxrbI1GwygIPHGcDrdm6fZWolzuLUlSs5unAiiKRJOTUVpaWr7o7z846HROpwuFEtdq'
    b'tchms37W6YynHBc2nZ3xj7e3P6JgrReA57WUSr2kq6uEUK2eDvf19TubzSbH8zxpNBozgIZ5'
    b'ftWgKB4ql/NgKPYCSJJCc3Mizc/P22VZsSOpimnA5DmOG2m326JOpxNKpQJtbaWp1ZJ7AZgG'
    b'i4uPOtFo9PX5+XmxVCrVIJZ9YmLiablcTiWTyXcLCwsxMHHv7LwnsOsFYDtJkjR6vX7Ebrf3'
    b'WSwWCRUtCNfRhmlsbGxSlmVTvV5nrnWT2YdTV1jgQCkUCt8zmcyVKIqRXC6X3d/ff7a3t/cG'
    b'oL7j4+PNm5ubbwBW01QXWIQxGBgYeDA6OnoLqoahoSF/p9Npu1yunzgbcTqdc2DggB5/A2i1'
    b'WorH45rd3d1pCAeRWoRKAdAmQRC6PWMfgh6UzWYJRbogKgN2MRwOUyQSqaBCA6d1dNQ0GAzj'
    b'ACtgz9oFgbq4srJCtdrvd6BqAKo0NTUlu93uTbB5Dhc2U6lUPBgMfoCwr0wm03qlUlmfmZn5'
    b'AoHxkP6wkfFBZd7hcCxZrdYMAIugfg8X7/v9fhN+NT6f7xNAPKy9u6EyYAFmD6qPp9Ppk6Oj'
    b'owuj0Rg8PDx8gbgelKuJROIEYv7bBbw2Am26vLzE27c9MZvNzXw+b4ady8ViUQQjORAI6K6v'
    b'r72sf5x3SagiMhfW1tZoY2ODqe66cwJxN6qy/wNzZfZOPK/X2wX4BaLZZI5jTh0zAAAAAElF'
    b'TkSuQmCC')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAEinpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja3VdJcgM3DLzzFXkCAXB9DjdU5Qd5fpqcxZYsKWPZySFDiwuIARtoEFM2'
    b'468/1fyBh12wxvmYQg7B4nHZZS6YJLs9ZfVk3erXw/sW1jdyc24wRIJRtmUKu/4hp9PANhTM'
    b'/CdDqe0b9XYju91+ujO0nywT0Zz33VDeDQlvG7QbKJtbNuQUP7tQxzb2w5O0/czsXLqF/WUd'
    b'Eb3ucY4wDyGx6Fl4AyDzR0YKJoSeRXiJlsSh93K4hIA8ipP9hMrcs3LO6In8jhQJm9xAcBvM'
    b'cI4P5eTv5LtBs0L86WRp58k3cp/P7LoJ8vyp9mRUx+ZdcQEhDbtThytrBsWKkMt6LaBF/Dzm'
    b'cbWMlgyyt4HybputaI0yMWhRctSpkNJYY6MGiI4HR4zMDaxMWZLImZtYA5bcbKQcJUuXBOYa'
    b'6BVI+cRC69y8jmuUcHAnaDLBGM1UMLP7jfbUkOpMeSKbzlgBF88kBIzJ3OyhBUJIjzzyK8BH'
    b'u38mrwIG/QpzgoPF1s1E9bTn1swjWUQLFD3G7a5R7LsBhAhne4AhAQM2kHgKZCNzJEIcE/gp'
    b'MJRYHFdQQN5zB0p2IgHkJJ5n451IS5c9b2LULBDhJUgENVkKuHIobMif6BJyqHjxznsffPTJ'
    b'Z1+CBBd8CCGGWfxKlOiijyHGmGKOJUlyyaeQYkom5VQyZ0Fx9DnkmFPOuRQcWmC54O0ChVIq'
    b'V6mu+hpqrKnmWhrSp7nmW2ixJdNyK527dNSJHnrsqedeBg2k0nDDjzDiSCOPokg1FXXqNWjU'
    b'pFnLyRqZjdYv7TprdLDGi6mpGE/W8GqMhwma5cRPzsAYOwLjcTKAhObJmU3kHJtJ3eTMZlQ2'
    b'8QyUfpLTaTIGBt0g9kondx/M3fBmnPsRb3wwZyZ1v8GcmdQ9Ye4rbw9Y6/Nr06yYxdC8hjOo'
    b'VnD9oFQ44Q/fpGPUZLkO1X26b2nVkayMuTL7Nh+Cd9fmXQNpm+qB3tgvblxwa/o0P7m7c1PX'
    b'YDOG2lvLlYOOLiMiSGAu9M5au7Yeg3DJXjJ3FPGIjPRqBzhpSJxZn6OGYCLHCmWoD7xb+gha'
    b'k5eSm6IkTVQV5R8f4oCjtDpw1RVU+hodcEYV3xMXb9xwFXVgWvexSfXryNyG69pzbnk5hQz2'
    b'WlYC5ToGuYHc7Oo28uDTvP0vXLL/6NHpkPmhR6dD5oVHz/w5+a8N13xPAfOa+uspYOzG/xh8'
    b'TFAYBF4Afq9V4WxPaSRamD/AtxBVGYEdfWifd0272+KBIJUtMLeWUmAp1s8gf0Q7Up74WsWA'
    b'UqDO2Cbq72ClYdtUy7GrhqGj0FNQuPELllm4fgJrgcIne+FasD7IGNRG/nQhr5BhrlzIK8ae'
    b'3v7HxeK5OXMlU05jL1aGL6u+Xpl9+S03Hnjxfqm9X5vjkB8b+hDYyy49Gs0z4r97gPkpkseG'
    b'bin9ljnzO3hg6L2I/DuIVkDMexF5cWm/N34NiPmdUL9j6EmKmN/Bc9HQlRT5zxBdvjT/0qX9'
    b'f5cRUfxbkPEt/xtjgtcEvAQmSwAAAYVpQ0NQSUNDIHByb2ZpbGUAAHicfZE9SMNQFIVPU6Ui'
    b'FQc7FHHIUJ0siIoILlqFIlQItUKrDiYv/YMmDUmKi6PgWnDwZ7Hq4OKsq4OrIAj+gLi5OSm6'
    b'SIn3JYUWMd7wyMd59xzeuw8QGhWmWV1jgKbbZjqZELO5VTH0igCiCNI3IzPLmJOkFHzr6566'
    b'qe7iPMu/78/qU/MWAwIi8SwzTJt4g3hq0zY47xNHWElWic+JR006IPEj1xWP3zgXXRZ4ZsTM'
    b'pOeJI8RisYOVDmYlUyOeJI6pmk75QtZjlfMWZ61SY61z8huG8/rKMtdpDSGJRSxBgggFNZRR'
    b'gY04/XVSLKRpP+HjH3T9ErkUcpXByLGAKjTIrh/8DX7P1ipMjHtJ4QTQ/eI4H8NAaBdo1h3n'
    b'+9hxmidA8Bm40tv+agOY/iS93tZiR0D/NnBx3daUPeByB4g+GbIpu1KQllAoAO9n9Ew5YOAW'
    b'6F3z5tbax+kDkKFZpW6Ag0NgpEjZ6z737umc2789rfn9AE1Ccpjs6S1dAAAPoGlUWHRYTUw6'
    b'Y29tLmFkb2JlLnhtcAAAAAAAPD94cGFja2V0IGJlZ2luPSLvu78iIGlkPSJXNU0wTXBDZWhp'
    b'SHpyZVN6TlRjemtjOWQiPz4KPHg6eG1wbWV0YSB4bWxuczp4PSJhZG9iZTpuczptZXRhLyIg'
    b'eDp4bXB0az0iWE1QIENvcmUgNC40LjAtRXhpdjIiPgogPHJkZjpSREYgeG1sbnM6cmRmPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4KICA8cmRmOkRl'
    b'c2NyaXB0aW9uIHJkZjphYm91dD0iIgogICAgeG1sbnM6aXB0Y0V4dD0iaHR0cDovL2lwdGMu'
    b'b3JnL3N0ZC9JcHRjNHhtcEV4dC8yMDA4LTAyLTI5LyIKICAgIHhtbG5zOnhtcE1NPSJodHRw'
    b'Oi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIgogICAgeG1sbnM6c3RFdnQ9Imh0dHA6Ly9u'
    b'cy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZUV2ZW50IyIKICAgIHhtbG5zOnBs'
    b'dXM9Imh0dHA6Ly9ucy51c2VwbHVzLm9yZy9sZGYveG1wLzEuMC8iCiAgICB4bWxuczpHSU1Q'
    b'PSJodHRwOi8vd3d3LmdpbXAub3JnL3htcC8iCiAgICB4bWxuczpkYz0iaHR0cDovL3B1cmwu'
    b'b3JnL2RjL2VsZW1lbnRzLzEuMS8iCiAgICB4bWxuczp0aWZmPSJodHRwOi8vbnMuYWRvYmUu'
    b'Y29tL3RpZmYvMS4wLyIKICAgIHhtbG5zOnhtcD0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAv'
    b'MS4wLyIKICAgeG1wTU06RG9jdW1lbnRJRD0iZ2ltcDpkb2NpZDpnaW1wOmRmNGNlZTA5LWQx'
    b'OTQtNGM0ZC1hYTU5LTZmYjYyOTRkYzEwOCIKICAgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlp'
    b'ZDoyZDNlNjI0My04ZDM5LTQ0MDItYmVkOC1jYjM1M2JjY2E3OWIiCiAgIHhtcE1NOk9yaWdp'
    b'bmFsRG9jdW1lbnRJRD0ieG1wLmRpZDpmOGU5MTI2ZC0zYWM4LTQ5MWMtOTcyZi1hNTQzNzQ3'
    b'ZmU3YjciCiAgIEdJTVA6QVBJPSIyLjAiCiAgIEdJTVA6UGxhdGZvcm09Ik1hYyBPUyIKICAg'
    b'R0lNUDpUaW1lU3RhbXA9IjE2MTE0NTc0OTY0NTQwMDEiCiAgIEdJTVA6VmVyc2lvbj0iMi4x'
    b'MC4yMiIKICAgZGM6Rm9ybWF0PSJpbWFnZS9wbmciCiAgIHRpZmY6T3JpZW50YXRpb249IjEi'
    b'CiAgIHhtcDpDcmVhdG9yVG9vbD0iR0lNUCAyLjEwIj4KICAgPGlwdGNFeHQ6TG9jYXRpb25D'
    b'cmVhdGVkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRpb25DcmVhdGVkPgog'
    b'ICA8aXB0Y0V4dDpMb2NhdGlvblNob3duPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6'
    b'TG9jYXRpb25TaG93bj4KICAgPGlwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICAgPHJkZjpC'
    b'YWcvPgogICA8L2lwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICA8aXB0Y0V4dDpSZWdpc3Ry'
    b'eUlkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6UmVnaXN0cnlJZD4KICAgPHhtcE1N'
    b'Okhpc3Rvcnk+CiAgICA8cmRmOlNlcT4KICAgICA8cmRmOmxpCiAgICAgIHN0RXZ0OmFjdGlv'
    b'bj0ic2F2ZWQiCiAgICAgIHN0RXZ0OmNoYW5nZWQ9Ii8iCiAgICAgIHN0RXZ0Omluc3RhbmNl'
    b'SUQ9InhtcC5paWQ6NWY3MDI4ZTEtMzJkYS00YzExLTgxZmEtNzNmYjI4YzhlM2QzIgogICAg'
    b'ICBzdEV2dDpzb2Z0d2FyZUFnZW50PSJHaW1wIDIuMTAgKE1hYyBPUykiCiAgICAgIHN0RXZ0'
    b'OndoZW49IjIwMjEtMDEtMjNUMjE6MDQ6NTYtMDY6MDAiLz4KICAgIDwvcmRmOlNlcT4KICAg'
    b'PC94bXBNTTpIaXN0b3J5PgogICA8cGx1czpJbWFnZVN1cHBsaWVyPgogICAgPHJkZjpTZXEv'
    b'PgogICA8L3BsdXM6SW1hZ2VTdXBwbGllcj4KICAgPHBsdXM6SW1hZ2VDcmVhdG9yPgogICAg'
    b'PHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VDcmVhdG9yPgogICA8cGx1czpDb3B5cmlnaHRP'
    b'd25lcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkNvcHlyaWdodE93bmVyPgogICA8cGx1'
    b'czpMaWNlbnNvcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkxpY2Vuc29yPgogIDwvcmRm'
    b'OkRlc2NyaXB0aW9uPgogPC9yZGY6UkRGPgo8L3g6eG1wbWV0YT4KICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgIAo8P3hwYWNrZXQgZW5kPSJ3Ij8+'
    b'Lm355QAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB+UB'
    b'GAMEOGy4tZIAAABVSURBVFjD7ZMxCgAgCAAt+v+XbWiVKJPCuIMGhULtLGKjEk+xks1zaZNp'
    b'M1Ues1iA6jjeOP8E7qOBmzB9iy9oJzv8tYTXRE09AcABwAHAAcABCHGgA6xsIwH1g5pVAAAA'
    b'AElFTkSuQmCC')





from enum import Enum

from wx import HORIZONTAL
from wx import VERTICAL


class DirectionEnum(Enum):
    """
    A type safe wrapper for wxPython's int values
    """

    Horizontal = HORIZONTAL
    Vertical   = VERTICAL



#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAADXnpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHjavZZreusoDIb/s4pZApIQiOVgLs9zdnCWPx++tUnTNmk9Y2qEZSwJvYLU'
    b'9b9/hvsHF/sQXdBkMcfocYUcMhcMzG9XWXvyYe33B38MbvTufMFQCaRsjxb3+Yee/I0lKhjp'
    b'O0NW9xfL7Yscdvt2Z4g3ITOiOW67obwbEt5e0G6gbMvyMVt6v4Slb7IdK7HtdrMLdhv2h+eE'
    b'7DWFH2HuQuLRs/AWgMybnBQMCD1J4jnyGIsE9CzHUpGQR3ny76Jy91TOEX2iv4MicdM7KG6T'
    b'GU/5UE96p98NujXF7zxLPT3f6JfldHGT5HmP0cyN0bfVlRCR0rgv6ljKOsLEBSmX9bOIlnAr'
    b'xmltGc0cqrcCefPVL2iVMjEyPihQo0KD+iorVYQYuDOQMHMFqKkzIMpcxTtwCrPR4CRZmhho'
    b'VeCd5PiMhVa/eXVXyeC4EWYywRjNUnCzu6J9amiMWfJE3s5cIS6eRYgwJrnZYxaA0DjqSNcE'
    b'H+3+mlwFBHVNs2GBxS+biUVpr61ZR7KCFkxUyG2vUWq7AaQIvhXBkICAjyRKkXxiTkTIo4FP'
    b'gSFjCbwAAalyQ5QcRCLgGE/f+CbROpeVNzXOLIBQiZKAJksBq4CDDfWTgqGGiooGVY2a1DRr'
    b'iRJD1BhjivPwK0lSSJpiSslSTsXEgqlFS2bOspXMWXA4ao45Zcs5lwKnBZYLvi6YUMrCiyxh'
    b'0SUuabElL6WifGqoWmNN1VzNtTRu0nBOtNhSs5Zb6dRRSj107bGnbj33MlBqQ0YYOuJIw0Ye'
    b'5aRGbsP6oT1PjQ5qvJKaE9NJDZ+mdJigeZzoZAZiHAjE0ySAgubJzBuFwG6im8x8ZuwKZUSp'
    b'E06jSQwEQyfWQSe7N3I33FwIv+LGBzk30V1Bzk10n5D7yO0BtTZ/baoXtxKa23Am1Qu2HyYV'
    b'NvzhN+lrKf1N5b6dO54z6773+8D/A/PuZ599lO6KaKZ0V0TzZI6eM+uuiOaJHD1v1l0Rzes5'
    b'+kK6n/l/Itk/zZb7XRz/NbVX5SvHiH/2mHFX5OfO0G/K8QX83xr6XRyX1dFbGO6K7fFyHT1O'
    b'w6b9/zbtczCku2uYXfsrck0luWs2yFmQr5mRgX9nMo6OfwEl19KFhbRE0QAAAYVpQ0NQSUND'
    b'IHByb2ZpbGUAAHicfZE9SMNQFIVPU6UiFRU7iDhEqU4WREUctQpFqBBqhVYdTF76B00akhQX'
    b'R8G14ODPYtXBxVlXB1dBEPwBcXNzUnSREu9LCi1ivfB4H+fdc3jvPkCoFplmtY0Dmm6biVhU'
    b'TKVXxcArfOhFD4YwLDPLmJOkOFrW1z11U91FeFbrvj+rS81YDPCJxLPMMG3iDeLpTdvgvE8c'
    b'YnlZJT4nHjPpgsSPXFc8fuOcc1ngmSEzmZgnDhGLuSZWmpjlTY14ijisajrlCymPVc5bnLVi'
    b'mdXvyV8YzOgry1ynNYgYFrEECSIUlFFAETYitOukWEjQebSFf8D1S+RSyFUAI8cCStAgu37w'
    b'P/g9Wys7OeElBaNA+4vjfIwAgV2gVnGc72PHqZ0A/mfgSm/4S1Vg5pP0SkMLHwHd28DFdUNT'
    b'9oDLHaD/yZBN2ZX8tIRsFng/o29KA323QOeaN7f6OU4fgCTNKn4DHBwCoznKXm/x7o7muf3b'
    b'U5/fD2jncqNSfiE1AAAPoGlUWHRYTUw6Y29tLmFkb2JlLnhtcAAAAAAAPD94cGFja2V0IGJl'
    b'Z2luPSLvu78iIGlkPSJXNU0wTXBDZWhpSHpyZVN6TlRjemtjOWQiPz4KPHg6eG1wbWV0YSB4'
    b'bWxuczp4PSJhZG9iZTpuczptZXRhLyIgeDp4bXB0az0iWE1QIENvcmUgNC40LjAtRXhpdjIi'
    b'PgogPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJk'
    b'Zi1zeW50YXgtbnMjIj4KICA8cmRmOkRlc2NyaXB0aW9uIHJkZjphYm91dD0iIgogICAgeG1s'
    b'bnM6aXB0Y0V4dD0iaHR0cDovL2lwdGMub3JnL3N0ZC9JcHRjNHhtcEV4dC8yMDA4LTAyLTI5'
    b'LyIKICAgIHhtbG5zOnhtcE1NPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIgog'
    b'ICAgeG1sbnM6c3RFdnQ9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNv'
    b'dXJjZUV2ZW50IyIKICAgIHhtbG5zOnBsdXM9Imh0dHA6Ly9ucy51c2VwbHVzLm9yZy9sZGYv'
    b'eG1wLzEuMC8iCiAgICB4bWxuczpHSU1QPSJodHRwOi8vd3d3LmdpbXAub3JnL3htcC8iCiAg'
    b'ICB4bWxuczpkYz0iaHR0cDovL3B1cmwub3JnL2RjL2VsZW1lbnRzLzEuMS8iCiAgICB4bWxu'
    b'czp0aWZmPSJodHRwOi8vbnMuYWRvYmUuY29tL3RpZmYvMS4wLyIKICAgIHhtbG5zOnhtcD0i'
    b'aHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wLyIKICAgeG1wTU06RG9jdW1lbnRJRD0iZ2lt'
    b'cDpkb2NpZDpnaW1wOmZlZDg0M2ZhLTcwNTQtNDk3Mi05NGU4LTJkOGE3M2M4ZTE5MCIKICAg'
    b'eG1wTU06SW5zdGFuY2VJRD0ieG1wLmlpZDpjYzIzYzkxMy1mZTE2LTQ0ZWMtOTFkMC0zNDA4'
    b'YzE2YjhmOTMiCiAgIHhtcE1NOk9yaWdpbmFsRG9jdW1lbnRJRD0ieG1wLmRpZDowNmRhNTUw'
    b'OC1lNzZlLTQ3N2UtYjA4ZS05N2M0NWE2NWJjYTMiCiAgIEdJTVA6QVBJPSIyLjAiCiAgIEdJ'
    b'TVA6UGxhdGZvcm09Ik1hYyBPUyIKICAgR0lNUDpUaW1lU3RhbXA9IjE2MTA5MDEyNjg2MzEz'
    b'ODAiCiAgIEdJTVA6VmVyc2lvbj0iMi4xMC4yMiIKICAgZGM6Rm9ybWF0PSJpbWFnZS9wbmci'
    b'CiAgIHRpZmY6T3JpZW50YXRpb249IjEiCiAgIHhtcDpDcmVhdG9yVG9vbD0iR0lNUCAyLjEw'
    b'Ij4KICAgPGlwdGNFeHQ6TG9jYXRpb25DcmVhdGVkPgogICAgPHJkZjpCYWcvPgogICA8L2lw'
    b'dGNFeHQ6TG9jYXRpb25DcmVhdGVkPgogICA8aXB0Y0V4dDpMb2NhdGlvblNob3duPgogICAg'
    b'PHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRpb25TaG93bj4KICAgPGlwdGNFeHQ6QXJ0'
    b'd29ya09yT2JqZWN0PgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6QXJ0d29ya09yT2Jq'
    b'ZWN0PgogICA8aXB0Y0V4dDpSZWdpc3RyeUlkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNF'
    b'eHQ6UmVnaXN0cnlJZD4KICAgPHhtcE1NOkhpc3Rvcnk+CiAgICA8cmRmOlNlcT4KICAgICA8'
    b'cmRmOmxpCiAgICAgIHN0RXZ0OmFjdGlvbj0ic2F2ZWQiCiAgICAgIHN0RXZ0OmNoYW5nZWQ9'
    b'Ii8iCiAgICAgIHN0RXZ0Omluc3RhbmNlSUQ9InhtcC5paWQ6ZjE0NTE1MmMtYWIxYy00MTlj'
    b'LWEyZjAtMTAxOGUwN2Y5ODQwIgogICAgICBzdEV2dDpzb2Z0d2FyZUFnZW50PSJHaW1wIDIu'
    b'MTAgKE1hYyBPUykiCiAgICAgIHN0RXZ0OndoZW49IjIwMjEtMDEtMTdUMTA6MzQ6MjgtMDY6'
    b'MDAiLz4KICAgIDwvcmRmOlNlcT4KICAgPC94bXBNTTpIaXN0b3J5PgogICA8cGx1czpJbWFn'
    b'ZVN1cHBsaWVyPgogICAgPHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VTdXBwbGllcj4KICAg'
    b'PHBsdXM6SW1hZ2VDcmVhdG9yPgogICAgPHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VDcmVh'
    b'dG9yPgogICA8cGx1czpDb3B5cmlnaHRPd25lcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVz'
    b'OkNvcHlyaWdodE93bmVyPgogICA8cGx1czpMaWNlbnNvcj4KICAgIDxyZGY6U2VxLz4KICAg'
    b'PC9wbHVzOkxpY2Vuc29yPgogIDwvcmRmOkRlc2NyaXB0aW9uPgogPC9yZGY6UkRGPgo8L3g6'
    b'eG1wbWV0YT4KICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAK'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgIAo8P3hwYWNrZXQgZW5kPSJ3Ij8+4zi33wAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlz'
    b'AAALEwAACxMBAJqcGAAAAAd0SU1FB+UBERAiHPANgMQAAABASURBVDjLY2TADv5jEWNkIBL8'
    b'J0WciYFCMPAGMNIiEIkJUNp54T8F3h4gL1BsADHO/0+N6PtPjYD7T41Qx5AHAEKCDwSsMq1l'
    b'AAAAAElFTkSuQmCC')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERpIDE2IEF1ZyAyMDA1IDEzOjU3OjUwICswMTAw0YaYRwAAAAd0SU1FB9MCDg4kJAUUyA8A'
    b'AAAJcEhZcwAACvAAAArwAUKsNJgAAAAEZ0FNQQAAsY8L/GEFAAAG+UlEQVR42sWWa2wU1xXH'
    b'z73z2Mfs2tj4gQHHWDbEtfOoQhqnQOOYAFZToIaIOumHSEWq4AuVQMhCVVoUKVFVtVWVNv1A'
    b'86FVkRrXjlpViVUaSrBkiLE3dox52IDfD+y1WXt37d2ZnbmPnlmbqEVtxQZQr3T2zuzMnfM7'
    b'/3vuuRfg/9zIf3tw+vRpTdf1fY5t72eO8zXTMvMdx+GOw2Ydxi6lUqlmn8/3t8bGRvHQAXp7'
    b'e785MT7+q5HhoVKTS9OXV5RQgzlcEkJYPEqT4YmAsxTzOBKuGYZx+MSJE5ceGkDf5cs/unKl'
    b'7+TIXCTxVF19OL+kxHKYBIcLYtmS2IwQi0sanxg2lnr+kRuZGlM9fuPIyZMn3/syAMo9kZ/o'
    b'+Sz0VjK4enbf915fWJe7Sg1Q4TGAe6hECMaArRjxZTmy7NlEQAUtMnTtlRe3vzTc3t7e96UB'
    b'erq7twxcv/6HuJE7t+eVvSZlQvEQqSlSKkCpBJAKBi4Zl5K5MA4ngjNw8srNPJ+qTfZ/vvf5'
    b'r29p6ezsnM8EgN69WFhY+PlgOGLV1O9ddGxOAwSMLEqDXoXoJheODeBoRFIGINC/TM8dXhBm'
    b'ksXSb0Q2Vj6t2Zb1k0wVSAO0trZW3+y/9vzG7d8KE5urHiCaCqAKEKBhjzKpqLrgQAQOoEJI'
    b'Il3/SMFREUNxqPbUjqimkG8fOnSoJGOAWDS6L2YxO/uxMgvjI1wIWHCEaXMpUhx4ghE7hY4s'
    b'xiQTGD6O4fgjcF2gCKArhIS1wmRpaSm1LHN3JgCq+2Oa5mYlpzBpYoqb+GlVUL52m17scHyG'
    b'mgccyFOwt9DcOfChGSv3t86MDwbVANGpAsb6jTbvu/JMxgBIvYauLmQsJUhUCkaBEtd5Ts0W'
    b'yGEOgG0vGyYd2Kkv7j+4OA8zEyP6qvIyiikjvdkFjNlOUcZTwN0PY5GxhSCmI+Tkkp1yIwfX'
    b'OU5+2nBa0vduv2Jul0wmKCYnLhYCVFHwv8wKY1oB23Zui0S82HEIiTm47hDLQl+3zobARiW4'
    b'WJbbXuldddyeL2ci8VFKFy3MjaU7GuP8dsYADuMhMj/9oslRBc6kTgn5uOX2zdnxYTVlJqm7'
    b'6tzAMA8JR+duIjIBJMUkKcoKaghGXKDE1JBGKO3KGEDTtL9YS9EfmuFRv7qq0HRwKYCqQ1ZR'
    b'CQeJi85VX6YdI8AyjInOcRUqlWv8ZDSuONX50v9RRwdDMVozzoHjx493E1Vvl1c+ybPAS1B+'
    b'ksLpEKofhBaQQg9IqRtAvdh7ApLjve4LkKfX5+oJ6RXhlCLh+t+zItH4X1taWqYyAfiiFO/c'
    b'uasvOjv1/Wwv1RZzSi3OGGFu5Fh/0YiD5d9my7Jn60Qvz/F446h9d5g7DQWRvN/87C09Oyd3'
    b'3datW6/V19c3PlddPXjxwoW5+wY4d+7c9M5ddfPxsf76AizAUX9JioCkqquSBKqpRAl6FG1d'
    b'QNENTVFGoo4YjhH+auFC3i/e+IHv5d17SVVVlTcYDL5WVPzYM9OTY+zTjktn7hvAbW1tbaFt'
    b'L9REZ29cfnmDGtNpVgGdEwEmMLMw42kyJclUgoiRJSGeyFU9VZELgV++/WNf7Y5d5ODBg6Cq'
    b'KlRWPUl6Otth9/l3njy1yu58Mwwj/wvgPx5Ijh07tjUei/46aPgeL99UYXvXVqS01YWWSlSh'
    b'mBEtNdnv+aStTQ/PRa4agWBObW1tZVlZGdTV1UFT0x/hK6OnoCgeh8DVCdM/HdlPPoMzGQHc'
    b'TdDDhw/vMJOJ/Yw5zzKHFQgs/ngwuY31P+TxeJqxXWhoaFiDzgcOHGjIHhgchAreDJvyKfjD'
    b'cYAx3Jm7By0YmfsO6YYPMwW4r3b06NFXKyor348nU/DcnQ9g8wtrwSjIxqKAJXsUc3DiDkIM'
    b'pWBo9rsI8ed7x6sPCoDr/vzAyHhzzcXf126o8uX7xj24U6H50DbkuyXeNdzhaZNUZl4nXdD0'
    b'UBW422QlVEXyjHOrt5UVQhnuR4+jGd7lmj62okTPCIPB6YMkBKfvjlMexOm/tjfnYO6nhU4r'
    b'RJb2gUcPusUUsnwAflQi6F2O1fBQsBJ7ap+o1gN1ByJdHZ+GH3gK/k3OLuiXX01sh65bZ/G4'
    b'VpzexSrWLYOkp4PBVf6S2pu7+43g8MBrOKScPrDXeyF64QYsJrdD6OYYDM0ADEzikSsJgEJE'
    b'12+G2S2NULY2T9q2/Tv3/YcOkIYIwSDMW6jE4CjcciEmYHaSQrT4CFRtKoHuUAhisdjFRwaw'
    b'osQwpKwa6LoxFBmIwtmlOlCJDc1/anJ3Xzf5jUcKkIbogHHct+veDeyRhqHDe789JTFymJmZ'
    b'aff7/R+n33mUAG57+513aXhs+Dye2ex4PH5EUZQA9p83NTXxR+37vto/Add4nsxxMlygAAAA'
    b'AElFTkSuQmCC')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERvIDE0IE5vdiAyMDAyIDIzOjMxOjQ0ICswMTAwhFAcSAAAAAd0SU1FB9MCGwAUCxzaSQIA'
    b'AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAACUUlEQVR42sWTXUiTURjH'
    b'/+/XdO+as40c4ta3QWWQK7FPRGLdeFHQxeiqD4KEjaBoUUHihRdFSBhIVtRFEDS7MQcVZIVC'
    b'RTCzafMrar2u2nIuN7f57ut9384GDoyom6IHDpznnOf/e57znHOA/23Ub3etTysgBc9pK437'
    b'S1hWPxOM+Di1ujf7oOninwEHh7YtM4g9bUe2G7MMIMSAlyFgdCiMWY+3E31WRz6M+aX40GTN'
    b'apP0rMux1dA7CQxPA4E4kEgD9FINZFZVJxv3BuXxu4NsQXBirGUJX1KbCHy0Qcow2rJo97Xm'
    b'Op1rBGBpknXwXXpKmHlCyRRfbq5qMGxey8Q8A01EeaMA2L2SumDbtYp1dPqdUDjV1aNb1vf7'
    b'AV4F9Lo9gXiOscPV6FZIbMLWf5LT6trVphU7ReLTecC3REpYrgdqa8znN2wyndLxNHIk+rVv'
    b'Kjcnsc50l8W9cLqsq+FK9FPAw2k0+rxfqOBDOOWlZKw5UF/NU4qEYdIsRVLwZiJ0X7pe7/q5'
    b'RVIyNkqX6CxYqICSJG9wLgc1R+YUg6oy4LHnPSAmK5jmwR7Y/YcXAbJ4mwxPfy4COLZ09qEv'
    b'AhMRcnQ+O2C3rkPr8cY9bccs+zaaqFtwRsqKBJoWZSk1XgSI5u5OIU7FS8mlcmQkCGBeBnxC'
    b'FDfd4+JESLyDy4a5IoBhGFrFDRR7AOcl+WvH6RE9jx2B7yIejSXwSpj3J2eifWnaeAYdldFF'
    b'TaDLn2djU4FFL5FrFc5WazMtE1+iLxhKfS/TXnObLCv/5AP9VfsBefzjkDmDLj0AAAAASUVO'
    b'RK5CYII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAAA8AAAAPCAYAAAA71pVKAAABhWlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kT1Iw1AUhU/TSotUFCwi4pChOlkQFXHUKhShQqgVWnUweekfNGlIWlwcBdeCgz+LVQcX'
    b'Z10dXAVB8AfEzc1J0UVKvC8ptIjxwuN9nHfP4b37AKFRZpoVGAc0vWqmEnExk10Vg6/woQ8D'
    b'CCAkM8uYk6QkPOvrnrqp7mI8y7vvz+pRcxYDfCLxLDPMKvEG8fRm1eC8TxxhRVklPiceM+mC'
    b'xI9cV1x+41xwWOCZETOdmieOEIuFDlY6mBVNjXiKOKpqOuULGZdVzluctXKNte7JXxjO6SvL'
    b'XKc1jAQWsQQJIhTUUEIZVcRo10mxkKLzuId/yPFL5FLIVQIjxwIq0CA7fvA/+D1bKz854SaF'
    b'40DXi21/jADBXaBZt+3vY9tungD+Z+BKb/srDWDmk/R6W4seAb3bwMV1W1P2gMsdYPDJkE3Z'
    b'kfy0hHweeD+jb8oC/bdA95o7t9Y5Th+ANM0qeQMcHAKjBcpe93h3qHNu//a05vcD7EZyccBA'
    b'tS4AAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAACxIAAAsSAdLdfvwAAAAHdElNRQflARAW'
    b'BQZrm9AMAAAAaElEQVQoz62S0Q3AIAgFH4Yl3MbRu03HwJ+aYC0Ibfkz8d4BCnwoup0lc3+B'
    b'j/OZb5UWpmTavILlFazsAgCctE4hHLDA2gNboAXoKlaLrdJkD8MjYISk4J3RnVkbvdk58jR/'
    b'/W2PzVUHml4lxjJDvWkAAAAASUVORK5CYII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAADsnpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja1VZbsuwmDPzXKrIEJPEQywEMVdlBlp/G9jjH87jX58xUKjHDwzI0olvA'
    b'UP/rz0F/4BGXPfmQLOYYHR6ffZaChrntKWvJzq/l/uJujZOdjg8Ck6LW7dXi3v9mZ3dC4oJW'
    b'+AJkbf9Qzx+y3/HtDki2SqdHs73sQHkHUtk+8A5QtmW5mC19XULtW73cVmJbpll4O7v98J7A'
    b'3hIwj4p0ZXUoRWVzQGdm0oIGo2RNMlt7G6Wo7WAg5BlP7otXdK/K0eIX9jtRNG52guFMZjzq'
    b'p3YOd/YdkFaKv8ys7Zj5ZO/1mOJE8sxjLEZj9G11xUdQGvdF3ZayttCxgnJdh0WkhBzQTmvK'
    b'SEaI3gbJF9dcRWqcWSDLYM8LFx7c17pxg4teukASEWkQatoMEmVp6ggK+Zl4SNKsixrUapBX'
    b'YZXDF17nzet0jQ0TL4yewgDjGQo0i0+kl0BjzJBndnZwBb9kBiHcmMrNEr0gCI9bHIWV4Fu6'
    b'f6auCgXDSrNhgcXVDaIG3mNrxpGuQis6BtTbXuO07ACgCHMHOIOo9+wia+DILokkZvBo0KcA'
    b'yES9VEjAIcgCL8WrRohjMufGmMRrXwmymXFmQYigERvJIFCBVvNgQ/wkb4ihEjT4EEIMKVjI'
    b'oUSNPoYYY4rz8CtJk08hxZSSpZyKqXkLFi2ZkWUrWbLicAw55pQt51wKJi1ALhhd0KGUKlWr'
    b'r6HGmqrVXEtD+DTfQostNaOWW1lk0QXnxBKXtNiSl9K5I5S676HHnrr13MtAqA0dfoQRRxo2'
    b'8iiHakybrA/pump8U01WpWbHdKiGoSndIHgeJ2FqBsXEMxRPUwEEtEzNnLH3QlO6qZnLgl0R'
    b'BF6GKc7CUzEo6DtLGHxo949yJ93I+7d0k5tyNKX7hHI0pXuh3KNuT1Rb5m3TnNKq0NyGk1Sn'
    b'2H7oVMTww510vabvDvhfAM2zwROya+t7mRf9j2v6yUCfcGd5uBCwI3bv6BP8/BJI+xgnEiYH'
    b'83Dem23UWlYHh3ktjb5LB4bFbXytmt0BRxve5WGj7zTtHLkbXQS+tPe+rqF2nnf8j1iiyQbz'
    b'jtNb97+Bfeg9xg50hcm34+gVs2f4tRddYvICkfTD+Hugik7zPGHyalDSRS5/W9MvuD3MV8ij'
    b'98Lw0qZ9HnivyKLvBt6HAvI1WfShPYv/2d8OveexRQdfbwYTXT8aHwn6egH8qxckX1k+vb3J'
    b'/uNAA3+YMk65vwGZnvBNCUlTKwAAAYVpQ0NQSUNDIHByb2ZpbGUAAHicfZE9SMNQFIVPU0WR'
    b'ioodRBwyVEGwICriqFUoQoVQK7TqYPLSP2jSkKS4OAquBQd/FqsOLs66OrgKguAPiJubk6KL'
    b'lHhfUmgR4w2PfJx3z+G9+wChVmKa1TYOaLptJuMxMZ1ZFTteEUAffb0YlZllzElSAr71dU/d'
    b'VHdRnuXf92d1q1mLAQGReJYZpk28QTy9aRuc94nDrCCrxOfEYyYdkPiR64rHb5zzLgs8M2ym'
    b'kvPEYWIx38JKC7OCqRFPEUdUTad8Ie2xynmLs1aqsMY5+Q1DWX1lmeu0hhDHIpYgQYSCCooo'
    b'wUaU/jopFpK0H/PxD7p+iVwKuYpg5FhAGRpk1w/+Br9na+UmJ7ykUAxof3Gcj2GgYxeoVx3n'
    b'+9hx6idA8Bm40pv+cg2Y+SS92tQiR0DPNnBx3dSUPeByBxh4MmRTdqUgLSGXA97P6JkyQP8t'
    b'0LXmza2xj9MHIEWzStwAB4fASJ6y133u3dk6t397GvP7AVJkcprCvuxqAAAPoGlUWHRYTUw6'
    b'Y29tLmFkb2JlLnhtcAAAAAAAPD94cGFja2V0IGJlZ2luPSLvu78iIGlkPSJXNU0wTXBDZWhp'
    b'SHpyZVN6TlRjemtjOWQiPz4KPHg6eG1wbWV0YSB4bWxuczp4PSJhZG9iZTpuczptZXRhLyIg'
    b'eDp4bXB0az0iWE1QIENvcmUgNC40LjAtRXhpdjIiPgogPHJkZjpSREYgeG1sbnM6cmRmPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4KICA8cmRmOkRl'
    b'c2NyaXB0aW9uIHJkZjphYm91dD0iIgogICAgeG1sbnM6aXB0Y0V4dD0iaHR0cDovL2lwdGMu'
    b'b3JnL3N0ZC9JcHRjNHhtcEV4dC8yMDA4LTAyLTI5LyIKICAgIHhtbG5zOnhtcE1NPSJodHRw'
    b'Oi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIgogICAgeG1sbnM6c3RFdnQ9Imh0dHA6Ly9u'
    b'cy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZUV2ZW50IyIKICAgIHhtbG5zOnBs'
    b'dXM9Imh0dHA6Ly9ucy51c2VwbHVzLm9yZy9sZGYveG1wLzEuMC8iCiAgICB4bWxuczpHSU1Q'
    b'PSJodHRwOi8vd3d3LmdpbXAub3JnL3htcC8iCiAgICB4bWxuczpkYz0iaHR0cDovL3B1cmwu'
    b'b3JnL2RjL2VsZW1lbnRzLzEuMS8iCiAgICB4bWxuczp0aWZmPSJodHRwOi8vbnMuYWRvYmUu'
    b'Y29tL3RpZmYvMS4wLyIKICAgIHhtbG5zOnhtcD0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAv'
    b'MS4wLyIKICAgeG1wTU06RG9jdW1lbnRJRD0iZ2ltcDpkb2NpZDpnaW1wOjIyZmM0ZGJlLTIz'
    b'NjEtNDA5Ni1hZmQ5LTc0YWEyYjJiZjE3NyIKICAgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlp'
    b'ZDo4ZGNhYmFhYy05NDZjLTRiYjAtYjRhNS1mY2U3MWQwOTA0NzUiCiAgIHhtcE1NOk9yaWdp'
    b'bmFsRG9jdW1lbnRJRD0ieG1wLmRpZDowNzQ5YmNhNS01NDcwLTQ1ZWItOGU3Zi00NjkzY2Nj'
    b'YmZiYWIiCiAgIEdJTVA6QVBJPSIyLjAiCiAgIEdJTVA6UGxhdGZvcm09Ik1hYyBPUyIKICAg'
    b'R0lNUDpUaW1lU3RhbXA9IjE2MTA5MDM4NTA0ODI1ODUiCiAgIEdJTVA6VmVyc2lvbj0iMi4x'
    b'MC4yMiIKICAgZGM6Rm9ybWF0PSJpbWFnZS9wbmciCiAgIHRpZmY6T3JpZW50YXRpb249IjEi'
    b'CiAgIHhtcDpDcmVhdG9yVG9vbD0iR0lNUCAyLjEwIj4KICAgPGlwdGNFeHQ6TG9jYXRpb25D'
    b'cmVhdGVkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRpb25DcmVhdGVkPgog'
    b'ICA8aXB0Y0V4dDpMb2NhdGlvblNob3duPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6'
    b'TG9jYXRpb25TaG93bj4KICAgPGlwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICAgPHJkZjpC'
    b'YWcvPgogICA8L2lwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICA8aXB0Y0V4dDpSZWdpc3Ry'
    b'eUlkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6UmVnaXN0cnlJZD4KICAgPHhtcE1N'
    b'Okhpc3Rvcnk+CiAgICA8cmRmOlNlcT4KICAgICA8cmRmOmxpCiAgICAgIHN0RXZ0OmFjdGlv'
    b'bj0ic2F2ZWQiCiAgICAgIHN0RXZ0OmNoYW5nZWQ9Ii8iCiAgICAgIHN0RXZ0Omluc3RhbmNl'
    b'SUQ9InhtcC5paWQ6M2JlNzgwOGYtZDI1Yi00Mzc1LWEwOGUtYTJiOTBiMTI2MmFkIgogICAg'
    b'ICBzdEV2dDpzb2Z0d2FyZUFnZW50PSJHaW1wIDIuMTAgKE1hYyBPUykiCiAgICAgIHN0RXZ0'
    b'OndoZW49IjIwMjEtMDEtMTdUMTE6MTc6MzAtMDY6MDAiLz4KICAgIDwvcmRmOlNlcT4KICAg'
    b'PC94bXBNTTpIaXN0b3J5PgogICA8cGx1czpJbWFnZVN1cHBsaWVyPgogICAgPHJkZjpTZXEv'
    b'PgogICA8L3BsdXM6SW1hZ2VTdXBwbGllcj4KICAgPHBsdXM6SW1hZ2VDcmVhdG9yPgogICAg'
    b'PHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VDcmVhdG9yPgogICA8cGx1czpDb3B5cmlnaHRP'
    b'd25lcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkNvcHlyaWdodE93bmVyPgogICA8cGx1'
    b'czpMaWNlbnNvcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkxpY2Vuc29yPgogIDwvcmRm'
    b'OkRlc2NyaXB0aW9uPgogPC9yZGY6UkRGPgo8L3g6eG1wbWV0YT4KICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgIAo8P3hwYWNrZXQgZW5kPSJ3Ij8+'
    b'44PVPQAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB+UB'
    b'ERERHuuq7u8AAABRSURBVDjLY2AY8oARSv8nVz8LjPXvTwVOVUwsHRjyTCwdEJoYa/79qYBr'
    b'wDCcWLfiMoSJFA9jM4SJ1FBDN4SJnKBHDlAmStMB04AnpKGflxgAtm0Wh1G4rz0AAAAASUVO'
    b'RK5CYII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAABhWlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kT1Iw1AUhU9TpSIVETuIOGSoThZERcRJq1CECqFWaNXB5KV/0KQhSXFxFFwLDv4sVh1c'
    b'nHV1cBUEwR8QNzcnRRcp8b6k0CLGC5f3cd47l/fOA4R6mWlWxxig6baZSsTFTHZVDL0igD5q'
    b'ETMys4w5SUrCt77u6STVXYzP8j/3Z/WoOYsBAZF4lhmmTbxBPLVpG5z3iSOsKKvE58SjJl2Q'
    b'+JHrisdvnAsuC3xmxEyn5okjxGKhjZU2ZkVTI54kjqqaTvOFjMcq5y3OWrnKmvfkLwzn9JVl'
    b'rlMPIYFFLEGijBRUUUIZNmK06qRYSNF+3Mc/6PolcinkKoGRYwEVaJBdP/gf/M7Wyk+Me5PC'
    b'caDzxXE+hoHQLtCoOc73seM0ToDgM3Clt/yVOjD9SXqtpUWPgN5t4OK6pSl7wOUOMPBkyKbs'
    b'SkFqIZ8H3s/om7JA/y3Qvebl1tzH6QOQpqySN8DBITBSoNnrPu/uas/t3zPN/H4AfJFyq461'
    b'vrwAAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAADsQAAA7EAZUrDhsAAAAHdElNRQflAREB'
    b'ITdqeOMAAAAANklEQVQ4y2NgGAWkgP/YBBnJNICRLAP+/4eYwciI0M+IZDJBNswAhG5G6riA'
    b'ojCgOBZGARUAAHfCEwMt0PAfAAAAAElFTkSuQmCC')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAAXNSR0IArs4c6QAAAGxlWElm'
    b'TU0AKgAAAAgABAEaAAUAAAABAAAAPgEbAAUAAAABAAAARgEoAAMAAAABAAIAAIdpAAQAAAAB'
    b'AAAATgAAAAAAAABfAAAAAQAAAF8AAAABAAKgAgAEAAAAAQAAACCgAwAEAAAAAQAAACAAAAAA'
    b'NxUjagAAAAlwSFlzAAAOnAAADpwBB5RT3QAAAQFJREFUWAntll0KgzAQhNfS3scjeBSP4Huh'
    b'LIW+eySP4H0KtY5x7KKxFElsoVkIG1nZ+Zz8oEiK5MC/O5DRgLquu7Zt+Rg953kuVVVN+lKW'
    b'Zder7jZGPTnOP7UoCsHYGk3TCMZaH9bZ3wtwOSvrG7JOAP4+rs7GB05CZYiq6tDuelM5nOS1'
    b'zh6R4ADQ4JcDpB/YV6sRBQBqnzoRDYAQyO+ciAowimcAQGBP4BTYWJwCWwwxf9xxt+ggThDb'
    b'NzoAxdzGdA5YF6IvAQGQATG/5HYFsDCcJ4CvO7A4BW6HKpcoeLYnAM29APOXglOYhhMA/lD6'
    b'nwRTijuFXorkQHLgJxx4AsxecgDon9v0AAAAAElFTkSuQmCC')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAABhGlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kTtIw1AUhv+miiIVEStIcchQnSyIijhqFYpQIdQKrTqY3PQFTRqSFBdHwbXg4GOx6uDi'
    b'rKuDqyAIPkDc3JwUXaTEc5NCixgPHO7Hf89/OPdcQKiXmWZ1jAOabpupRFzMZFfFrlcE0E85'
    b'iIjMLGNOkpLwja97qqS4i/Fe/nV/Rq+asxgQEIlnmWHaxBvE05u2wXmfOMyKskp8Tjxm0oDE'
    b'j1xXPH7jXHBZ4D3DZjo1TxwmFgttrLQxK5oa8RRxVNV06i9kPFY5b3HWylXWnJO/MJTTV5a5'
    b'TjmMBBaxBAkiFFRRQhk2YnTqpFhI0X3cxx9x/RK5FHKVwMixgAo0yK4f/A9+79bKT054nUJx'
    b'oPPFcT5GgK5doFFznO9jx2mcAMFn4Epv+St1YOaT9FpLix4BfdvAxXVLU/aAyx1g6MmQTdmV'
    b'gpRCPg+8n9E3ZYGBW6Bnzdtb8x6nD0CadpW8AQ4OgdEC9V73eXd3+97+rWnu7wcRfHKAsQUM'
    b'igAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAAAd0SU1FB+UBEQEW'
    b'D9J9+6oAAAAtSURBVDjLY2AYBejgP6kaGHFoZiTVgP8EDMdrwH9K/EwVF1AUBhTHwiigAgAA'
    b'vGcHA5JjdeUAAAAASUVORK5CYII=')

